@@ -27,7 +27,7 @@ async def get_state(hub, ctx) -> Dict[str, Any]:
     """
     esm_profile = await hub.esm.aws.generate_esm_profile(ctx)
     try:
-        client = hub.tool.boto3.client.get_client(ctx, service_name="s3")
+        client = await hub.tool.boto3.client.get_client(ctx, service_name="s3")
         content = client.get_object(
             Bucket=esm_profile.get("bucket"),
             Key=esm_profile.get("key"),
@@ -142,7 +142,7 @@ async def enter(hub, ctx):
     try:
         # Put item with conditional expression to acquire the lock. The conditional check and put operation is atomic.
         # This ensures that the S3 bucket file can be locked properly.
-        db_resource = hub.tool.boto3.resource.create(
+        db_resource = await hub.tool.boto3.resource.create(
             ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
         )
         db_resource.put_item(
@@ -185,7 +185,7 @@ async def exit_(hub, ctx, handle: pathlib.Path, exception: Exception):
         raise ValueError("ESM profile is required to support remote ESM storage.")
     try:
         # Delete item with conditional expression to release the lock
-        db_resource = hub.tool.boto3.resource.create(
+        db_resource = await hub.tool.boto3.resource.create(
             ctx, "dynamodb", "Table", esm_profile.get("dynamodb_table")
         )
         db_resource.delete_item(
