@@ -8,17 +8,12 @@ async def get(
     Get a single API Gateway Integration from AWS. The function returns None if no resource is found.
 
     Args:
-        hub:
-
-        ctx:
-
         resource_id(str):
             Idem Resource ID that is generated once the resource is created,
-                formatted as: rest_api_id-parent_resource_id-http_method.
+            formatted as: rest_api_id-parent_resource_id-http_method.
 
         name(str, Optional):
             An Idem name of the API Gateway Integration.
-
     """
     result = dict(comment=[], ret=None, result=True)
 
