@@ -64,14 +64,13 @@ async def get(
 async def list_(
     hub,
     ctx,
-    name,
+    name: str = None,
 ) -> Dict:
     """Fetch a list of log_group from AWS.
-
     The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name (str, Optional):
             The name of the Idem state.
     """
     result = dict(comment=[], ret=[], result=True)
