@@ -148,7 +148,7 @@ async def get(
 async def list_(
     hub,
     ctx,
-    name: str,
+    name: str = None,
     executable_users: List = None,
     owners: List = None,
     include_deprecated: bool = False,
@@ -160,31 +160,31 @@ async def list_(
     Fetch a list of ami from AWS. The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name(str, Optional):
             The name of the Idem state.
 
-        executable_users (list[str], Optional):
+        executable_users(list[str], Optional):
             Scopes the images by users with explicit launch permissions.
             Specify an Amazon Web Services account ID, self (the sender of the request), or all (public AMIs).
 
-        owners (list[str], Optional):
+        owners(list[str], Optional):
             Scopes the results to images with the specified owners.
             You can specify a combination of Amazon Web Services account IDs, self , amazon , and aws-marketplace.
-            If you omit this parameter, the results include all images for which you have launch permissions, regardless of ownership.
+            If no value is specified, the default value is ["self"].
 
-        include_deprecated (bool, Optional):
-            If true , all deprecated AMIs are included in the response.
-            If false , no deprecated AMIs are included in the response. If no value is specified, the default value is false .
+        include_deprecated(bool, Optional):
+            If true, all deprecated AMIs are included in the response.
+            If false, no deprecated AMIs are included in the response. If no value is specified, the default value is false.
 
-        filters (list, Optional):
+        filters(list, Optional):
             One or more filters, A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images
 
-        tags (dict, Optional):
+        tags(dict, Optional):
             The dict of tags to filter by in the format ``{tag-key: tag-value}`` . For example, to find all resources
             that have a tag with the key "Owner" and the value "TeamA" , specify ``{Owner: TeamA}``
 
-            * Key (str):
+            * Key(str):
                 The key name for the tag to be used to filter by.
 
             * Value(str):
@@ -199,7 +199,7 @@ async def list_(
 
         .. code-block:: bash
 
-            idem exec aws.ec2.ami.list name="my_resources" filters=[{'name': 'name', 'values': ['ami-name']}, {'name': 'virtualization-type', 'values': ['hvm']}]
+            idem exec aws.ec2.ami.list filters=[{'name': 'name', 'values': ['ami-name']}, {'name': 'virtualization-type', 'values': ['hvm']}]
 
         Using in a state:
 
@@ -209,7 +209,6 @@ async def list_(
               exec.run:
                 - path: aws.ec2.ami.list
                 - kwargs:
-                    name: my_resources
                     filters:
                         - name: 'name'
                           values: ["ami-name"]
