@@ -91,7 +91,7 @@ async def bootstrap(
 
     if verify or auto_configure:
         verify_ssh_ret = await hub.exec.aws.ec2.instance.verify_ssh(
-            ctx, instance_id=instance_id
+            ctx, instance_id=instance_id, auto_configure=auto_configure
         )
         result["result"] &= verify_ssh_ret.result
         result["comment"] += verify_ssh_ret.comment
@@ -152,7 +152,7 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
 
         .. code-block:: bash
 
-            idem exec aws.ec2.instance.verify_ssh <instance_id>
+            $ idem exec aws.ec2.instance.verify_ssh <instance_id> auto_configure=True
     """
     result = dict(result=True, comment=[], ret=None)
 
@@ -161,25 +161,33 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
 
     # Verify that the instance is in a state with all the right permissions
     if not instance.state["Name"] == "running":
-        result["comment"] += ["Instance is not running"]
-        if not auto_configure:
+        if auto_configure:
+            # start the instance
+            ret = await hub.exec.aws.ec2.instance.start(ctx, instance_id=instance.id)
+            result["result"] &= ret
+            if ret.comment:
+                result["comment"].append(ret.comment)
+        else:
             result["result"] = False
+            result["comment"] += [
+                "Instance is not running, run the following command to start the instance"
+            ]
+            result["comment"] += [
+                f"$ idem exec aws.ec2.instance.start instance_id={instance.id}"
+            ]
             return result
-        # TODO start the instance
 
     if not instance.vpc.vpc_id:
+        # Instances must have a vpc, this is a sanity check
         result["comment"] += [f"No vpc attached to instance"]
-        if not auto_configure:
-            result["result"] = False
-            return result
-        # TODO attach the default vpc
+        result["result"] = False
+        return result
 
     if not instance.subnet.subnet_id:
+        # Instances must have a subnet, this is a sanity check
         result["comment"] += [f"No subnet attached to instance"]
-        if not auto_configure:
-            result["result"] = False
-            return result
-        # TODO attach the default subnet for the instance's availability zone
+        result["result"] = False
+        return result
 
     # Verify that an internet gateway is attached to the instance's vpc
     internet_gateway_ret = await hub.exec.boto3.client.ec2.describe_internet_gateways(
@@ -188,17 +196,49 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
             {"Name": "attachment.vpc-id", "Values": [instance.vpc.vpc_id]},
         ],
     )
-    if not internet_gateway_ret.result and internet_gateway_ret.ret["InternetGateways"]:
-        result["comment"] += [
-            f"No internet gateway attached to instance's vpc: {instance.vpc.vpc_id}"
-        ]
-        if not auto_configure:
-            result["result"] = False
-        # TODO attach an internet gateway to the vpc
 
-    internet_gateway_ids = [
-        igw["InternetGatewayId"] for igw in internet_gateway_ret.ret["InternetGateways"]
-    ]
+    if not internet_gateway_ret.result and internet_gateway_ret.ret["InternetGateways"]:
+        if auto_configure:
+            # Create a new internet gateway
+            igw_ret = await hub.exec.boto3.client.ec2.create_internet_gateway(ctx)
+            result["result"] &= igw_ret.result
+            if igw_ret.comment:
+                result["comment"] += [igw_ret.comment]
+            if not result["result"]:
+                return result
+
+            internet_gateway_id = igw_ret.ret["InternetGatewayId"]
+            result["comment"] += [f"Created internet gateway: {internet_gateway_id}"]
+
+            # attach the internet gateway to the instance's vpc
+            attach_ret = await hub.exec.boto3.client.ec2.attach_internet_gateway(
+                ctx, InternetGatewayId=internet_gateway_id, VpcId=instance.vpc.vpc_id
+            )
+            result["result"] &= attach_ret.result
+            if attach_ret.comment:
+                result["comment"] += [attach_ret.comment]
+            if not result["result"]:
+                return result
+
+            result["comment"] += [
+                f"Attached internet gateway '{internet_gateway_id}' to {instance.vpc.vpc_id}"
+            ]
+            internet_gateway_ids = [internet_gateway_id]
+        else:
+            result["comment"] += [
+                f"No internet gateway attached to instance's vpc: {instance.vpc.vpc_id}",
+                "Run the following command to attach an internet gateway to the instance's vpc",
+                f"$ idem exec boto3.client.ec2.create_internet_gateway --output=json > igw.json",
+                "$ IGW_ID=\"${jq -r '.ret.InternetGatewayId' igw.json}\"",
+                f"$ idem exec boto3.client.ec2.attach_internet_gateway InternetGatewayId=$IGW_ID VpcId={instance.vpc.vpc_id}",
+            ]
+            result["result"] = False
+            return result
+    else:
+        internet_gateway_ids = [
+            igw["InternetGatewayId"]
+            for igw in internet_gateway_ret.ret["InternetGateways"]
+        ]
 
     # Verify that there is a route with 0.0.0.0/0 as the destination and the internet gateway for your VPC as the target
     ipv4_route_table_ret = await hub.exec.boto3.client.ec2.describe_route_tables(
@@ -236,10 +276,12 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
 
     # If there is still no route table then add a command to the comments that would enable it
     if not has_route_table:
-        if not auto_configure:
+        if auto_configure:
+            # TODO configure route table
+            ...
+        else:
             # At least one ipv4 or ipv6 route table must be configured for SSH
             result["result"] = False
-        # TODO configure route table
 
         # Get the first internet gateway to use in an example
         igw_id = next(iter(internet_gateway_ids))
@@ -258,7 +300,7 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
             # Get the id of the main route table
             rt_id = next(iter(try_route_table.ret["RouteTables"]))["RouteTableId"]
             result["comment"] += [
-                f"idem exec boto3.client.ec2.create_route RouteTableID={rt_id} VpcEndpointId={instance.vpc.vpc_id} DestinationCidrBlock='0.0.0.0/0' GatewayId={igw_id}"
+                f"$ idem exec boto3.client.ec2.create_route RouteTableID={rt_id} VpcEndpointId={instance.vpc.vpc_id} DestinationCidrBlock='0.0.0.0/0' GatewayId={igw_id}"
             ]
 
     # Verify that the ACL for the subnet allows inbound traffic
@@ -272,9 +314,11 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
     )
     if not (network_acl_ret and network_acl_ret.ret["NetworkAcls"]):
         result["comment"] += [f"No valid ACL"]
-        if not auto_configure:
+        if auto_configure:
+            # TODO configure network acl
+            ...
+        else:
             result["result"] = False
-        # TODO configure network acl
 
     return result
 
@@ -447,12 +491,13 @@ async def start(hub, ctx, instance_id: str):
         ctx, InstanceIds=[instance_id]
     )
     if ret.comment:
-        result["comments"].append(ret.comment)
+        result["comment"].append(ret.comment)
     if not ret.result:
-        return False
+        result["result"] &= ret.result
+        return result
 
     resource = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
-    await hub.tool.boto3.resource.exec(ctx, resource, "wait_until_running")
+    await hub.tool.boto3.resource.exec(resource, "wait_until_running")
 
     return result
 
@@ -467,12 +512,13 @@ async def stop(hub, ctx, instance_id: str):
         ctx, InstanceIds=[instance_id], Hibernate=False, Force=False
     )
     if ret.comment:
-        result["comments"].append(ret.comment)
+        result["comment"].append(ret.comment)
     if not ret.result:
-        return False
+        result["result"] &= ret.result
+        return result
 
     resource = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
-    await hub.tool.boto3.resource.exec(ctx, resource, "wait_until_stopped")
+    await hub.tool.boto3.resource.exec(resource, "wait_until_stopped")
 
     return result
 
@@ -498,6 +544,10 @@ async def get(
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances.
     """
     result = dict(comment=[], ret=None, result=True)
+    if filters:
+        filters = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
+            filters=filters
+        )
     if resource_id:
         ret = await hub.exec.boto3.client.ec2.describe_instances(
             ctx, InstanceIds=[resource_id], Filters=filters
@@ -515,7 +565,7 @@ async def get(
         return result
 
     present_states = await hub.tool.aws.ec2.instance.state.convert_to_present(
-        ctx, ret.ret
+        ctx, ret.ret, name=name
     )
 
     # If the resource can't be found but there were no results then "result" is True and "ret" is None
@@ -533,10 +583,10 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, *, name=None, filters: List = None) -> Dict:
+async def list_(hub, ctx, *, name: str = None, filters: List = None) -> Dict:
     """
     Args:
-        name(str):
+        name(str, Optional):
             The name of the Idem state.
 
         filters(list, Optional):
@@ -544,6 +594,10 @@ async def list_(hub, ctx, *, name=None, filters: List = None) -> Dict:
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances.
     """
     result = dict(comment=[], ret=[], result=True)
+    if filters:
+        filters = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
+            filters=filters
+        )
     ret = await hub.exec.boto3.client.ec2.describe_instances(
         ctx,
         Filters=filters,
