@@ -22,6 +22,10 @@ async def get(
 
     """
     result = dict(comment=[], ret=None, result=True)
+    if filters:
+        filters = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
+            filters=filters
+        )
 
     if resource_id:
         ret = await hub.exec.boto3.client.ec2.describe_network_interfaces(
@@ -63,13 +67,20 @@ async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     Use an un-managed Network INterface as a data-source. Supply one of the inputs as the filter.
 
     Args:
-        name(str): The name of the Idem state.
-        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_network_interfaces
+        name(str, Optional):
+            The name of the Idem state.
+
+        filters(list, Optional):
+            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_network_interfaces
 
     """
 
     result = dict(comment=[], ret=[], result=True)
+    if filters:
+        filters = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
+            filters=filters
+        )
     ret = await hub.exec.boto3.client.ec2.describe_network_interfaces(
         ctx,
         Filters=filters,
