@@ -85,14 +85,15 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name, filters: List = None) -> Dict:
+async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     """Get a list of EC2 placement group resources from AWS. Supply one of the inputs as the filter.
 
     Get a list of placement groups by idem name (group name) or filters.
 
     Args:
-        name(str):
-            The name of the Idem state and the GroupName of the placement group.
+        name(str, Optional):
+            The name of the Idem state.
+
         filters(list, Optional):
             One or more filters: for example, tag :<key>, tag-key.
             A complete list of filters can be found at
@@ -115,7 +116,6 @@ async def list_(hub, ctx, name, filters: List = None) -> Dict:
     result = dict(comment=[], ret=[], result=True)
     ret = await hub.tool.aws.ec2.placement_group.search_raw(
         ctx=ctx,
-        name=name,
         filters=filters,
     )
     if not ret["result"]:
