@@ -93,17 +93,14 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name: str, filters: List = None) -> Dict:
+async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     """
     Get a list of SecurityGroup resources from AWS. Supply one of the inputs as the filter.
 
     Args:
-        name (str):
+        name (str, Optional):
             The name of the Idem state.
 
-        resource_id (str, Optional):
-            ID of the security group.
-
         filters (list[str, str], Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_security_groups
