@@ -143,7 +143,7 @@ async def get(
 async def list_(
     hub,
     ctx,
-    name,
+    name: str = None,
     availability_zone: str = None,
     availability_zone_id: str = None,
     cidr_block: str = None,
@@ -159,7 +159,7 @@ async def list_(
     Fetch a list of subnets AWS. The function returns empty list when no resource is found.
 
     Args:
-        name(str):
+        name(str, Optional):
             The name of the Idem state.
 
         availability_zone(str, Optional):
@@ -254,4 +254,5 @@ async def list_(
                 raw_resource=subnet, idem_resource_name=subnet_id
             )
         )
+
     return result
