@@ -28,26 +28,27 @@ async def get(
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpc_peering_connections
 
     Examples:
-        Calling this exec module function from the cli with resource_id
+        Calling from the CLI:
 
         .. code-block:: bash
 
-            idem exec aws.ec2.vpc_peering_connection.get resource_id="resource_id" name="name"
+            $ idem exec aws.ec2.vpc_peering_connection.get
 
+        Using in a state:
 
-        Calling this exec module function from the cli with filters.
-        The filters can be passed as a json string that will be parsed into a python structure by idem's config loader.
+        .. code-block:: yaml
 
-        .. code-block:: bash
-
-            idem exec aws.ec2.vpc_peering_connection.get filters='[{"name": "filter_name", "values": ["filter_value1"]}]'
-
-        Calling this exec module function from within a state module in pure python
-
-        .. code-block:: python
-
-            async def state_function(hub, ctx, name, resource_id, **kwargs):
-                ret = await hub.exec.aws.ec2.vpc_peering_connection.get(ctx, resource_id=resource_id, name=name, **kwargs)
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.ec2.vpc_peering_connection.get
+                - kwargs:
+                    name: some-idem-resource-name
+                    resource_id: some-resource-id
+                    filters:
+                      - name: 'vpc-peering-connection-id'
+                        values: ["pcx-ae89ce9b"]
+                      - name: 'tag:Name'
+                        values: ["my_unmanaged_resource"]
     """
     result = await hub.tool.aws.ec2.vpc_peering_connection_utils.get_vpc_peering_connection_raw(
         ctx, name, resource_id, "aws.ec2.vpc_peering_connection", filters
