@@ -37,12 +37,16 @@ async def get(hub, ctx, resource_id: str, name: str = None) -> Dict:
     return result
 
 
-async def list_(hub, ctx, name: str) -> Dict:
-    """List AWS Guardduty detectors.
+async def list_(hub, ctx, name: str = None) -> Dict:
+    """List AWS guard duty detectors.
 
     Args:
-        name(str):
-            Name of the Idem state.
+        name(str, Optional):
+            Name of the Idem state for logging purposes.
+
+    Returns:
+        Dict[str, Any]:
+            Return detectors.
     """
     result = dict(comment=[], ret=[], result=True)
     before = await hub.exec.boto3.client.guardduty.list_detectors(ctx)
