@@ -23,9 +23,35 @@ async def list_(
     Returns a list of access keys for a user_name, optionally filtering by status and access_key_id.
 
     Args:
-        user_name: The user_name to list keys for.
-        access_key_id (Optional): match exact access key to return
-        status (Optional): match "Active" or "Inactive" keys; "Active" means the key is valid for API calls.
+        user_name (str):
+            The user_name to list keys for.
+
+        access_key_id (str, Optional):
+            match exact access key to return
+
+        status (str, Optional):
+            match "Active" or "Inactive" keys; "Active" means the key is valid for API calls.
+
+    Returns:
+        dict[str, Any]:
+            Returns a list of access keys for the user
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.access_key.list user_name="a_user"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.access_key.list
+                - kwargs:
+                    user_name: a_user
     """
     # we manually filter status, so we must validate it
     if status not in [None, "Active", "Inactive"]:
@@ -88,9 +114,37 @@ async def update(
     Updates the status of an existing access key. Does not execute if ctx["test"] is True.
 
     Args:
-        user_name: exact user that owns the key
-        access_key_id: exact access key to update
-        status: "Active" or "Inactive", meaning it is valid for API calls.
+        user_name (str):
+            Exact user that owns the key
+
+        access_key_id (str):
+            Exact access key to update
+
+        status (str):
+            "Active" or "Inactive", meaning it is valid for API calls
+
+    Returns:
+        dict[str, Any]:
+            Status of the update
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.access_key.update user_name="a_user" access_key_id="ABCDEF0123456789ABCD" status="Active"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.access_key.update
+                - kwargs:
+                    user_name: a_user
+                    access_key_id: ABCDEF0123456789ABCD
+                    status: Active
     """
     result = {"result": True, "ret": None, "comment": ()}
     # this should never happen and would result in unexpected behavior
@@ -126,8 +180,33 @@ async def delete(hub, ctx, user_name: str, access_key_id: str) -> Dict[str, Any]
     "result" is False if there is an error deleting the key
 
     Args:
-        user_name: exact user owning the key
-        access_key_id: exact access key to delete
+        user_name (str):
+            Exact user owning the key
+
+        access_key_id (str):
+            Exact access key to delete
+
+    Returns:
+        dict[str, Any]:
+            Status of the deletion
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.access_key.delete user_name="a_user" access_key_id="ABCDEF0123456789ABCD"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.access_key.delete
+                - kwargs:
+                    user_name: a_user
+                    access_key_id: ABCDEF0123456789ABCD
     """
     result = {"result": True, "ret": None, "comment": ()}
     # this should never happen and would result in unexpected behavior
@@ -157,9 +236,35 @@ async def create(hub, ctx, user_name: str, pgp_key: str = None) -> Dict[str, Any
     Creates a new access key for the specified user.
 
     Args:
-        user_name: exact user the key will be created for.
-        pgp_key (Optional): base 64 encoded public pgp key with which we will encrypt the returned secret_access_key.
+        user_name (str):
+            Exact user the key will be created for.
+        pgp_key (str, Optional):
+            Base 64 encoded public pgp key with which we will encrypt the returned secret_access_key.
 
+    Returns:
+        dict[str, Any]:
+            Access key ID, Secret access key, status
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.access_key.create user_name="a_user" pgp_key="-----BEGIN PGP PUBLIC KEY BLOCK-----0123456789ABCDEFxxxETC-----END PGP PUBLIC KEY BLOCK-----"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.access_key.create
+                - kwargs:
+                    user_name: a_user
+                    pgp_key:
+                        -----BEGIN PGP PUBLIC KEY BLOCK-----
+                        0123456789ABCDEFxxxETC
+                        -----END PGP PUBLIC KEY BLOCK-----
     """
 
     result = {"result": True, "ret": None, "comment": ()}
