@@ -3,8 +3,6 @@ import copy
 from typing import Any
 from typing import Dict
 
-__func_alias__ = {"list_": "list"}
-
 
 async def get(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
     """Get an IAM role from AWS.
@@ -16,7 +14,7 @@ async def get(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
             AWS IAM role name.
 
     Returns:
-        Dict[str, Any]:
+        dict[str, Any]:
             Retrieves information about the specified role.
 
     Examples:
@@ -74,15 +72,39 @@ async def update_role_tags(
     Update tags of AWS IAM Role
 
     Args:
-        hub: The redistributed pop central hub.
-        ctx: A dict with the keys/values for the execution of the Idem run located in
-        `hub.idem.RUNS[ctx['run_name']]`.
-        role_name: AWS IAM role name
-        old_tags: dict of old tags
-        new_tags: dict of new tags
+        role_name (str):
+            AWS IAM role name
+
+        old_tags (dict):
+            A dict of old tags
+
+        new_tags (dict):
+            A dict of new tags
 
     Returns:
-        {"result": True|False, "comment": Tuple, "ret": Dict of updated tags}
+        dict[str, Any]:
+            Returns a dict of updated tags
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.role.update_role_tags role_name="some_role" old_tags='{"old_tag": "old_val"}' new_tags='{"new_tag": "new_val"}'
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.role.update_role_tags
+                - kwargs:
+                    role_name: some_role
+                    old_tags:
+                      old_tag: old_val
+                    new_tags:
+                      new_tag: new_val
     """
     tags_to_add = {}
     tags_to_remove = {}
@@ -134,6 +156,46 @@ async def update_role(
     max_session_duration: int = None,
     timeout: Dict = None,
 ):
+    """
+    Updates the description or maximum session duration setting of a role
+
+    Args:
+        old_state (dict):
+            Old role state
+
+        description (str):
+            The new description that you want to apply to the specified role
+
+        max_session_duration (int):
+            The maximum session duration (in seconds) for the specified role
+
+        timeout (dict):
+            Timeout (in seconds)
+
+    Returns:
+        dict[str, Any]:
+            Returns a dict of updated tags
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.role.update_role old_state='{}' role_name="some_role" description="Some description" max_session_duration=3600
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.role.update_role
+                - kwargs:
+                    old_state: {}
+                    role_name: some_role
+                    description: Some description
+                    max_session_duration: 3600
+    """
     result = dict(comment=(), result=True, ret=None)
     update_payload = {}
     if (description is not None) and old_state.get("description") != description:
@@ -190,7 +252,38 @@ async def update_policy(
     role_name: str,
     policy: str,
 ):
-    # Update role's trust policy (the policy that is embedded within the role)
+    """
+    Updates the policy that grants an IAM entity permission to assume a role
+
+    Args:
+        role_name (str):
+            The name of the role to update with the new policy
+
+        policy (dict):
+            The policy that grants an entity permission to assume the role
+
+    Returns:
+        dict[str, Any]:
+            Returns status of the update
+
+    Examples:
+        Calling this exec module function from the cli
+
+        .. code-block:: bash
+
+            idem exec aws.iam.role.update_policy role_name="some_role" policy='{}'
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            my_unmanaged_resource:
+              exec.run:
+                - path: aws.iam.role.update_policy
+                - kwargs:
+                    role_name: some_role
+                    policy: {}
+    """
     result = dict(comment=(), result=True, ret=None)
 
     if not ctx.get("test", False):
