@@ -114,11 +114,12 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name) -> Dict:
+async def list_(hub, ctx, name: str = None) -> Dict:
     """Use a list of un-managed neptune db cluster parameter groups as a data-source.
 
     Args:
-        name(str): The name of idem state.
+        name (str, Optional):
+            The name of idem state.
 
     .. note::
         At the time of writing this module, filters parameter is not supported for this resource as per
