@@ -103,13 +103,14 @@ async def get(
     return result
 
 
-async def list_(hub, ctx, name, filters: List = None) -> Dict:
+async def list_(hub, ctx, name: str = None, filters: List = None) -> Dict:
     """Use a list of un-managed neptune db instances as a data-source. Supply one of the inputs as the filter.
 
     Args:
-        name(str):
+        name (str, Optional):
             The name of idem state.
-        filters(list, Optional):
+
+        filters (list, Optional):
             A filter that specifies one or more DB instances to describe.
             Supported filters are,
 
