@@ -88,13 +88,14 @@ async def get(
 async def list_(
     hub,
     ctx,
-    name,
+    name: str = None,
 ) -> Dict:
     """
     Use an un-managed db_cluster_parameter_groups as a data-source.
 
     Args:
-        name(str): The name of the Idem state.
+        name (str, Optional):
+            The name of the Idem state.
 
     """
     result = dict(comment=[], ret=None, result=True)
