@@ -365,7 +365,7 @@ async def present(
     max_instance_lifetime: int = None,
     desired_capacity_type: str = None,
 ) -> Dict[str, Any]:
-    r"""Creates an Auto Scaling group with the specified name and attributes.
+    """Creates an Auto Scaling group with the specified name and attributes.
 
     We strongly recommend using a launch template when calling this operation to ensure full functionality for Amazon
     EC2 Auto Scaling and Amazon EC2.
@@ -1249,7 +1249,7 @@ async def absent(
     resource_id: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified Auto Scaling group.
+    """Deletes the specified Auto Scaling group.
 
     If the group has instances or scaling activities in progress, you must specify the option to force the deletion
     in order for it to succeed.
@@ -1392,7 +1392,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Gets information about the Auto Scaling groups in the account and Region.
+    """Gets information about the Auto Scaling groups in the account and Region.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
