@@ -14,7 +14,7 @@ async def present(
     hub,
     ctx,
     name: str,
-    launch_config_name: str,
+    name_prefix: str = None,
     resource_id: str = None,
     image_id: str = None,
     key_name: str = None,
@@ -69,20 +69,29 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Creates an AWS Launch Configuration.
+    """Creates an AWS Launch Configuration.
 
     If you exceed your maximum limit of launch configurations, the call fails. To query this limit, call the
     DescribeAccountLimits API. For information about updating this limit, see Amazon EC2 Auto Scaling service quotas in
     the Amazon EC2 Auto Scaling User Guide.
 
+    .. Note::
+        When using `aws.autoscaling.launch_configuration` with `aws.autoscaling.auto_scaling_group`, it is recommended
+        to use the `name_prefix` instead of the `name` argument. This will allow Idem's `recreate_on_update` requisite
+        to detect changes to the launch configuration and update the autoscaling group correctly.
+
+
     For more information, see Launch configurations in the Amazon EC2 Auto Scaling User Guide.
 
     Args:
         name(str):
-            Idem name of the launch configuration.
+            The name of the launch configuration. This name must be unique per Region per account.
 
-        launch_config_name(str):
-            The name of the aws launch configuration. This name must be unique per Region per account.
+        name_prefix(str, Optional):
+            Creates a unique name beginning with the specified prefix.
+
+            .. Note::
+                Either `name` or `name_prefix` should be specified.
 
         resource_id(str, Optional):
             AWS Launch Configuration name.
@@ -333,7 +342,6 @@ async def present(
             [launch_configuration-resource-id]:
               aws.autoscaling.launch_configuration.present:
                 - name: 'string'
-                - launch_config_name: 'string'
                 - resource_id: 'string'
                 - image_id: 'string'
                 - key_name: 'string'
@@ -361,8 +369,7 @@ async def present(
             idem-test-launch_configuration:
               aws.autoscaling.launch_configuration.present:
                 - name: idem-test-launch_configuration
-                - launch_config_name: test-launch_configuration
-                - resource_id: test-launch_configuration
+                - resource_id: idem-test-launch_configuration
                 - image_id: ami-73949613
                 - key_name: test-n
                 - security_groups:
@@ -402,14 +409,58 @@ async def present(
                     HttpPutResponseHopLimit: 64
                     HttpTokens: optional
 
+    Using with AutoScaling Groups:
+        Launch Configurations cannot be updated after creation with the Amazon Web Service API. In order to update a
+        Launch Configuration, Idem will destroy the existing resource and create a replacement. In order to effectively
+        use a Launch Configuration resource with an AutoScaling Group resource, it's recommended to specify
+        `create_before_destroy` in `recreate_on_update` requisite and specify a partial name with `name_prefix`.
+
+        Example:
+            .. code-block:: sls
+
+                idem-test-launch_configuration:
+                  aws.autoscaling.launch_configuration.present:
+                    - name_prefix: idem-test
+                    - associate_public_ip_address: false
+                    - iam_instance_profile: arn:aws:iam::537227425989:instance-profile/aws-elasticbeanstalk-ec2-role
+                    - instance_type: t2.micro
+                    - image_id: ami-73949613
+                    - security_groups:
+                      - sg-00bbd7b8d31f6bcad
+                      - sg-03064434ef6546344
+                    - user_data: /etc/eks/bootstrap.sh
+                    - key_name: test-n
+                    - block_device_mappings:
+                        - DeviceName: /dev/sda
+                          Ebs:
+                            DeleteOnTermination: true
+                            VolumeSize: 128
+                            VolumeType: gp3
+                            Encrypted: true
+                    - ignore_changes: ["key_name"]
+                    - recreate_on_update:
+                        create_before_destroy: true
+
+                idem-test-autoscaling_group:
+                  aws.autoscaling.auto_scaling_group.present:
+                    - name: idem-test-autoscaling_group
+                    - launch_configuration_name: ${aws.autoscaling.launch_configuration:idem-test-launch_configuration:resource_id}
+                    - min_size: 1
+                    - max_size: 2
+                    - desired_capacity: 1
+                    - vpc_zone_identifier: subnet-09b9b12ccde1074ed
+
+            With this setup Idem generates a unique name for your Launch Configuration and can then update the
+            AutoScaling Group without conflict before destroying the previous Launch Configuration.
+
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     launch_configuration_created = False
     before = None
     desired_state = {
         "name": name,
-        "resource_id": launch_config_name,
-        "launch_config_name": launch_config_name,
+        "resource_id": name,
+        "name_prefix": name_prefix,
         "image_id": image_id,
         "key_name": key_name,
         "security_groups": security_groups,
@@ -431,7 +482,7 @@ async def present(
     }
 
     launch_conf_args = {
-        "LaunchConfigurationName": launch_config_name,
+        "LaunchConfigurationName": name,
         "ImageId": image_id,
         "KeyName": key_name,
         "SecurityGroups": security_groups,
@@ -465,8 +516,9 @@ async def present(
             raw_resource=before["ret"]["LaunchConfigurations"][0],
             idem_resource_name=name,
         )
-        result["comment"] = (
-            f"aws.autoscaling.launch_configuration '{name}' already exists",
+        result["old_state"]["name_prefix"] = name_prefix
+        result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            resource_type="aws.autoscaling.launch_configuration", name=resource_id
         )
         result["new_state"] = copy.deepcopy(result["old_state"])
         return result
@@ -475,8 +527,8 @@ async def present(
             result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
                 enforced_state={}, desired_state=desired_state
             )
-            result["comment"] = (
-                f"Would create aws.autoscaling.launch_configuration '{name}'",
+            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+                resource_type="aws.autoscaling.launch_configuration", name=name
             )
             return result
 
@@ -490,11 +542,11 @@ async def present(
                 result["comment"] = ret["comment"]
                 return result
 
-            result["comment"] = (
-                f"Created aws.autoscaling.launch_configuration '{name}'",
+            result["comment"] = hub.tool.aws.comment_utils.create_comment(
+                resource_type="aws.autoscaling.launch_configuration", name=name
             )
             launch_configuration_created = True
-            resource_id = launch_config_name
+            resource_id = name
         except hub.tool.boto3.exception.ClientError as e:
             result["comment"] = result["comment"] + (f"{e.__class__.__name__}: {e}",)
             result["result"] = False
@@ -512,6 +564,7 @@ async def present(
                 raw_resource=after["ret"]["LaunchConfigurations"][0],
                 idem_resource_name=name,
             )
+            result["new_state"]["name_prefix"] = name_prefix
     except Exception as e:
         result["comment"] = result["comment"] + (str(e),)
         result["result"] = False
@@ -519,7 +572,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes the specified AWS Launch Configuration.
+    """Deletes the specified AWS Launch Configuration.
 
     The launch configuration must not be attached to an Auto Scaling group.
     When this call completes, the launch configuration is no longer available for use.
@@ -598,7 +651,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists AWS Launch Configurations in the account and Region.
+    """Lists AWS Launch Configurations in the account and Region.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
