@@ -625,7 +625,7 @@ async def absent(
     name: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes a trail.
+    """Deletes a trail.
 
     This operation must be called from the region in which the trail was created. DeleteTrail
     cannot be called on the shadow trails (replicated trails in other regions) of a trail that is enabled in all
@@ -697,7 +697,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists trails that are in the current account including Logging Status, Event Selectors and Insight Selectors as well.
+    """Lists trails that are in the current account including Logging Status, Event Selectors and Insight Selectors as well.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
