@@ -90,7 +90,7 @@ async def present(
         )
     ] = None,
 ):
-    r"""Creates or updates an alarm and associates it with the specified metric, metric math expression, or anomaly detection model.
+    """Creates or updates an alarm and associates it with the specified metric, metric math expression, or anomaly detection model.
 
     Alarms based on anomaly detection models cannot have Auto Scaling actions.
 
@@ -609,7 +609,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes the specified alarms.
+    """Deletes the specified alarms.
 
     You can delete up to 100 alarms in one operation. However, this total can include no
     more than one composite alarm. For example, you could delete 99 metric alarms and one composite alarms with one
@@ -693,7 +693,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Retrieves the specified alarms.
+    """Retrieves the specified alarms.
 
     You can filter the results by specifying a prefix for the alarm name, the alarm state, or a prefix for any action.
     To use this operation and return information about composite alarms, you must be signed on with the
