@@ -2,7 +2,6 @@
 import copy
 from dataclasses import field
 from dataclasses import make_dataclass
-from datetime import datetime
 from typing import Any
 from typing import Dict
 from typing import List
@@ -504,153 +503,17 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     """
     result = {}
-    ret = await hub.exec.boto3.client.ec2.describe_images(ctx)
+    ret = await hub.exec.aws.ec2.ami.list(ctx)
     if not ret["result"]:
         hub.log.debug(f"Could not describe AMI {ret['comment']}")
         return {}
 
-    for image in ret["ret"].get("Images"):
-        resource_id = image.get("ImageId")
-        resource_translated = (
-            hub.tool.aws.ec2.conversion_utils.convert_raw_ami_to_present(
-                raw_resource=image
-            )
-        )
-        result[resource_id] = {
+    for image in ret["ret"]:
+        result[image.get("resource_id")] = {
             "aws.ec2.ami.present": [
                 {parameter_key: parameter_value}
-                for parameter_key, parameter_value in resource_translated.items()
+                for parameter_key, parameter_value in image.items()
             ]
         }
 
     return result
-
-
-async def search(
-    hub,
-    ctx,
-    name,
-    filters: List = None,
-    resource_id: str = None,
-    executable_users: List = None,
-    owners: List = None,
-    include_deprecated: bool = False,
-    most_recent: bool = True,
-):
-    """
-    Use an un-managed AMI as a data-source. Supply one of the inputs as the filter.
-
-    Args:
-        name(str):
-            The name of the Idem state.
-
-        resource_id(str, Optional):
-            AWS image id to identify the resource.
-
-        executable_users(list, Optional):
-            Scopes the images by users with explicit launch permissions.
-            Specify an Amazon Web Services account ID, self (the sender of the request), or all (public AMIs).
-
-        owners(list, Optional):
-            Scopes the results to images with the specified owners.
-            You can specify a combination of Amazon Web Services account IDs, self , amazon , and aws-marketplace.
-            If you omit this parameter, the results include all images for which you have launch permissions, regardless of ownership.
-
-        include_deprecated(bool, Optional):
-            If true , all deprecated AMIs are included in the response.
-            If false , no deprecated AMIs are included in the response. If no value is specified, the default value is false .
-
-        most_recent(bool, Optional):
-            If more than one result is returned, use the most recent AMI.
-
-        filters(list, Optional):
-            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-            `boto3: EC2.Client.describe_images <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images>`__
-
-
-    Request Syntax:
-        .. code-block:: sls
-
-            [Idem-state-name]:
-              aws.ec2.ami.search:
-                - resource_id: "string"
-                - executable_users
-                  - user1
-                - owners
-                  - amazon
-                - include_deprecated: True|False
-                - most_recent: True|False
-                - filters:
-                    - name: "string"
-                      values: "list"
-                    - name: "string"
-                      values: "list"
-
-    Examples:
-        .. code-block:: sls
-
-            my-unmanaged-ami:
-              aws.ec2.ami.search:
-                - resource_id: value
-                - most_recent: False
-                - filters:
-                    - name: "name"
-                      values: ["amzn-ami-minimal-hvm-2018.03.0.20181129-x86_64-ebs_2"]
-    """
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-    syntax_validation = hub.tool.aws.search_utils.search_filter_syntax_validation(
-        filters=filters
-    )
-    if not syntax_validation["result"]:
-        result["comment"] = syntax_validation["comment"]
-        return result
-    boto3_filter = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
-        filters=filters
-    )
-
-    ami_args = {}
-    if boto3_filter:
-        ami_args["Filters"] = boto3_filter
-    if resource_id:
-        ami_args["ImageIds"] = [resource_id]
-    if executable_users:
-        ami_args["ExecutableUsers"] = executable_users
-    if owners:
-        ami_args["Owners"] = owners
-    if include_deprecated:
-        ami_args["IncludeDeprecated"] = include_deprecated
-
-    ret = await hub.exec.boto3.client.ec2.describe_images(ctx, **ami_args)
-
-    if not ret["result"]:
-        result["result"] = False
-        result["comment"] = ret["comment"]
-        return result
-
-    if not ret["ret"]["Images"]:
-        result["result"] = False
-        result["comment"] = (f"Unable to find aws.ec2.ami '{name}'",)
-        return result
-
-    resource = ret["ret"]["Images"][0]
-    result["comment"] = (f'Found aws.ec2.ami resource {resource.get("ImageId")}',)
-    if len(ret["ret"]["Images"]) > 1:
-        if most_recent:
-            ret["ret"]["Images"].sort(
-                key=lambda x: datetime.strptime(
-                    x.get("CreationDate"), "%Y-%m-%dT%H:%M:%S.%fZ"
-                ),
-                reverse=True,
-            )
-            resource = ret["ret"]["Images"][0]
-        else:
-            result["comment"] = (
-                f'More than one aws.ec2.ami resource was found. Use resource {resource.get("ImageId")}',
-            )
-
-    result["old_state"] = hub.tool.aws.ec2.conversion_utils.convert_raw_ami_to_present(
-        raw_resource=resource
-    )
-    # Populate both "old_state" and "new_state" with the same data
-    result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
