@@ -1,5 +1,3 @@
-import base64
-import copy
 import datetime
 from dataclasses import field
 from dataclasses import make_dataclass
@@ -115,7 +113,7 @@ async def present(
     disable_api_termination: bool = None,
     ram_disk_id: str = None,
     tags: Dict[str, str] = None,
-    iam_profile_arn: str = None,
+    iam_instance_profile_arn: str = None,
     instance_initiated_shutdown_behavior: str = None,
     elastic_inference_accelerators: List[
         make_dataclass(
@@ -238,22 +236,22 @@ async def present(
         resource_id(str):
             AWS Ec2 Instance ID.
 
-        image_id(str):
+        image_id(str, Optional):
             The ID of an AMI.
 
-        instance_type(str):
+        instance_type(str, Optional):
             The instance type to use for this instance on creation.
 
-        volume_attachments(dict[str, str]):
+        volume_attachments(dict[str, str], Optional):
             The instance device name mapped to a volume id.
 
-        ebs_optimized(bool):
+        ebs_optimized(bool, Optional):
             Indicates whether the instance is optimized ofr Amazon EBS I/O.
 
-        kernel_id(str):
+        kernel_id(str, Optional):
             The kernel associated with this instance, if applicable.
 
-        subnet_id(str):
+        subnet_id(str, Optional):
             The ID of the subnet in which the instance is running.
 
         network_interfaces(list[dict[str, Any]], Optional):
@@ -366,61 +364,61 @@ async def present(
                 The number of IPv6 delegated prefixes to be automatically assigned to the network interface. You
                 cannot use this option if you use the Ipv6Prefix option.
 
-        monitoring_enabled(bool):
+        monitoring_enabled(bool, Optional):
             Indicates whether detailed monitoring is enabled.
 
-        source_dest_check(bool):
+        source_dest_check(bool, Optional):
             Indicates whether source/destination checking is enabled.
 
-        running(bool):
+        running(bool, Optional):
             Indicates whether the instance should be in the "running" state.
 
-        private_ip_address(str):
+        private_ip_address(str, Optional):
             The Ipv4 address of the network interface within the subnet.
 
-        owner_id(str):
+        owner_id(str, Optional):
             The ID of the AWS account that owns the reservation.
 
-        availability_zone(str):
+        availability_zone(str, Optional):
             The Availability Zone of the instance.
 
-        affinity(str):
+        affinity(str, Optional):
             The affinity setting for the instance on the Dedicated Host.
 
-        group_name(str):
+        group_name(str, Optional):
             The affinity setting for the instance on the Dedicated Host.
 
-        partition_number(int):
+        partition_number(int, Optional):
             The number of the partition that the instance is in.
 
-        host_id(str):
+        host_id(str, Optional):
             The ID of the Dedicated Host on which the instance resides.
 
-        tenancy(str):
+        tenancy(str, Optional):
             The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware.
 
-        spread_domain(str):
+        spread_domain(str, Optional):
             Not yet documented by AWS.
 
-        host_resource_group_arn(str):
+        host_resource_group_arn(str, Optional):
             The ARN of the host resource group in which to launch the instances.
 
-        user_data(str):
+        user_data(str, Optional):
             The user data for the instance.
 
-        disable_api_termination(bool):
+        disable_api_termination(bool, Optional):
             Indicates that an instance cannot be terminated using the Amazon Ec2 console, command line tool, or API.
 
-        ram_disk_id(str):
+        ram_disk_id(str, Optional):
             The ID of the RAM disk, if applicable.
 
-        tags(dict, Optional):
+        tags(dict, Optional, Optional):
             The tags to apply to the resource. Defaults to None.
 
-        iam_profile_arn(str):
+        iam_instance_profile_arn(str, Optional):
             The IAM instance profile ARN.
 
-        instance_initiated_shutdown_behavior(str): Indicates whether an instance stops or terminates when you initiate
+        instance_initiated_shutdown_behavior(str, Optional): Indicates whether an instance stops or terminates when you initiate
             shutdown from the instance (using the operating system command for system shutdown).
 
         elastic_inference_accelerators(list[dict[str, Any]], Optional):
@@ -445,16 +443,16 @@ async def present(
                 Type, see Elastic Graphics Basics, specifically the Elastic Graphics accelerator column, in the
                 Amazon Elastic Compute Cloud User Guide for Windows Instances.
 
-        auto_recovery_enabled(bool):
+        auto_recovery_enabled(bool, Optional):
             Disables the automatic recovery behavior of your instance or sets it to default.
 
-        sriov_net_support(str):
+        sriov_net_support(str, Optional):
             Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
 
-        key_name(str):
+        key_name(str, Optional):
             The name of the keypair.
 
-        nitro_enclave_enabled(bool):
+        nitro_enclave_enabled(bool, Optional):
             Indicates whether the instance is enabled for AWS Nitro Enclaves.
 
         capacity_reservation_specification(dict[str, Any], Optional):
@@ -483,16 +481,16 @@ async def present(
                 * CapacityReservationResourceGroupArn (str, Optional):
                     The ARN of the Capacity Reservation resource group in which to run the instance.
 
-        client_token(str):
+        client_token(str, Optional):
             The idempotency token for the instance.
 
-        root_device_name(str):
+        root_device_name(str, Optional):
             The device name of the root device (for example, /dev/sda1).
 
         product_codes(list[dict[str, str]]:
             The product codes attached to the instance, if applicable.
 
-        reservation_id(str):
+        reservation_id(str, Optional):
             The ID of the reservation
 
         block_device_mappings(list[dict[str, Any]], Optional):
@@ -569,42 +567,42 @@ async def present(
             * NoDevice (str, Optional): To omit the device from the block device mapping, specify an empty string. When this property is
                 specified, the device is removed from the block device mapping regardless of the assigned value.
 
-        license_arns(list[str]):
+        license_arns(list[str], Optional):
             The license configuration arns.
 
-        hibernation_enabled(bool):
+        hibernation_enabled(bool, Optional):
             Indicates whether the instance is configured for hibernation.
 
-        market_type(str):
+        market_type(str, Optional):
             The market (purchasing) option for the instance.
 
-        max_price(str):
+        max_price(str, Optional):
             The maximum hourly price you're willing to pay for the Spot Instances.
 
-        spot_instance_type(str):
+        spot_instance_type(str, Optional):
             The Spot Instance request type. Persistent Spot Instance requests are only supported when the instance
             interruption behavior is either hibernate or stop.
 
-        block_duration_minutes(int):
+        block_duration_minutes(int, Optional):
             Deprecated.
 
-        valid_until(str):
+        valid_until(str, Optional):
             The end date of the request, in UTC format (YYYY -MM -DD T*HH* :MM :SS Z). Supported only for persistent requests.
 
-        instance_interruption_behavior(str):
+        instance_interruption_behavior(str, Optional):
             The behavior when a Spot Instance is interrupted. The default is terminate.
 
-        cpu_credits(str):
+        cpu_credits(str, Optional):
             The credit option for CPU usage of a T2, T3, or T3a instance. Valid values are standard and unlimited.
 
-        cpu_core_count(int):
+        cpu_core_count(int, Optional):
             The number of CPU cores for the instance.
 
-        cpu_threads_per_core(int):
+        cpu_threads_per_core(int, Optional):
             The number of threads per CPU core. To disable multithreading for the instance, specify a value of1 .
             Otherwise, specify the default value of 2.
 
-        http_tokens(str):
+        http_tokens(str, Optional):
             The state of token usage for your instance metadata requests. If the state is optional, you can
             choose to retrieve instance metadata with or without a signed token header on your request. If
             you retrieve the IAM role credentials without a token, the version 1.0 role credentials are
@@ -614,43 +612,43 @@ async def present(
             credentials always returns the version 2.0 credentials; the version 1.0 credentials are not
             available. Default: Optional.
 
-        http_put_response_hop_limit(int):
+        http_put_response_hop_limit(int, Optional):
             The desired HTTP PUT response hop limit for instance metadata requests. The larger the number,
             the further instance metadata requests can travel. Default: 1 Possible values: Integers from 1
             to 64.
 
-        http_endpoint_enabled(bool):
+        http_endpoint_enabled(bool, Optional):
             Enables or disables the HTTP metadata endpoint on your instances. If you specify a value of
             disabled, you cannot access your instance metadata. Default: enabled.
 
-        http_protocol_ipv6_enabled(str):
+        http_protocol_ipv6_enabled(str, Optional):
             Enables or disables the IPv6 endpoint for the instance metadata service.
 
-        metadata_tags_enabled(bool):
+        metadata_tags_enabled(bool, Optional):
             Set to enabled to allow access to instance tags from the instance metadata. Set to disabled to
             turn off access to instance tags from the instance metadata. For more information, see Work with
             instance tags using the instance metadata. Default: disabled.
 
-        hostname_type(str):
+        hostname_type(str, Optional):
             The type of hostname for EC2 instances.
             For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address.
             For IPv6 only subnets, an instance DNS name must be based on the instance ID.
             For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
 
-        enable_resource_name_dns_a_record(bool):
+        enable_resource_name_dns_a_record(bool, Optional):
             Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
 
-        enable_resource_name_dns_aaaa_record(bool):
+        enable_resource_name_dns_aaaa_record(bool, Optional):
             Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
 
-        capacity_reservation_preference(str):
+        capacity_reservation_preference(str, Optional):
             Indicates the instance's Capacity Reservation preferences.
 
-        instance_requirements(dict[str, Any]):
+        instance_requirements(dict[str, Any], Optional):
             The attributes for the instance type. When you specify instance attributes, Amazon EC2 will identify
             instance types with these attributes.
 
-        bootstrap(list[dict[str, Any]]):
+        bootstrap(list[dict[str, Any]], Optional):
             Bootstr options for provisioning an instance with "heist".
 
     Request Syntax:
@@ -673,39 +671,94 @@ async def present(
     Examples:
         .. code-block:: sls
 
-            resource_is_present:
-              aws.ec2.instance.present:
-                - name: value
-                - image_id: my_ami_id-0000000000000000
-                - tags:
-                    my_tag_key_1: my_tag_value_1
-                    my_tag_key_2: my_tag_value_2
-                - bootstrap:
-                    - heist_manager: salt.minion
-                      artifact_version: 1234
+            default_vpc:
+              exec.run:
+                - path: aws.ec2.vpc.get
+                - kwargs:
+                    default: "true"
 
+            default_subnet:
+              exec.run:
+                - path: aws.ec2.subnet.get
+                - kwargs:
+                    filters:
+                      - name: vpc-id
+                        values:
+                          - ${exec:default_vpc:resource_id}
+
+            small_image:
+              exec.run:
+                - path: aws.ec2.ami.get
+                - kwargs:
+                    owners:
+                      - amazon
+                    most_recent: True
+                    filters:
+                      - name: image-type
+                        values:
+                          - machine
+                      - name: state
+                        values:
+                          - available
+                      - name: hypervisor
+                        values:
+                          - xen
+                      - name: architecture
+                        values:
+                          - x86_64
+                      - name: root-device-type
+                        values:
+                          - ebs
+                      - name: virtualization-type
+                        values:
+                          - hvm
+
+            small_instance_type:
+              exec.run:
+                - path: aws.ec2.instance_type.get
+                - kwargs:
+                    filters:
+                      - name: instance-type
+                        values:
+                          - '*.nano'
+                      - name: hypervisor
+                        values:
+                          - xen
+                      - name: processor-info.supported-architecture
+                        values:
+                          - x86_64
+
+            create_instance:
+              aws.ec2.instance.present:
+                - subnet_id: ${exec:default_subnet:resource_id}
+                - image_id: ${exec:small_image:resource_id}
+                - instance_type: ${exec:small_instance_type:resource_id}
+                - client_token: optional-idempotence-token
+                - tags:
+                    Name: test-idem-cloud-demo
+                - bootstrap:
+                    heist_manager: salt.minion
+                    auto_configure: True
     """
+    # Convert a list of dictionaries to a plain dictionary before calculating desired_state
+    if isinstance(tags, list):
+        tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
+
     # Get all the parameters passed to this function as a single dictionary
     desired_state = {
         k: v
         for k, v in locals().items()
-        if k not in ("hub", "ctx", "name", "resource_id", "kwargs") and v is not None
+        if k not in ("hub", "ctx", "kwargs") and v is not None
     }
 
     result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
 
-    for key in kwargs:
-        result["comment"] += [f"Not explicitly supported keyword argument: '{key}'"]
-
     # Get the resource_id from ESM
     if not resource_id:
         resource_id = (ctx.old_state or {}).get("resource_id")
 
+    current_state = None
     if resource_id:
-        # Assume that the instance already exists since we have a resource_id
-        resource = await hub.tool.boto3.resource.create(
-            ctx, "ec2", "Instance", resource_id
-        )
         get = await hub.exec.aws.ec2.instance.get(
             ctx, name=name, resource_id=resource_id
         )
@@ -718,8 +771,22 @@ async def present(
             return result
 
         result["comment"] += [f"Instance '{name}' already exists"]
-    else:
-        # Create the instance if it doesn't already exist
+    elif client_token:
+        get = await hub.exec.aws.ec2.instance.get(
+            ctx, name=name, filters=[{"Name": "client-token", "Values": [client_token]}]
+        )
+
+        current_state = result["old_state"] = get.ret
+        if not result["old_state"]:
+            result["comment"] += [
+                f"Could not find instance for '{name}' with existing idempotence token '{client_token}'"
+            ]
+
+        else:
+            resource_id = current_state.resource_id
+            result["comment"] += [f"Instance '{name}' already exists"]
+
+    if not resource_id:
         if ctx.test:
             result["new_state"] = hub.tool.aws.ec2.instance.state.test(**desired_state)
             result["comment"] += [f"Would create aws.ec2.instance '{name}'"]
@@ -878,7 +945,9 @@ async def present(
             TagSpecifications=tag_specifications,
             ElasticGpuSpecifications=elastic_gpu_specifications,
             ElasticInferenceAccelerators=elastic_inference_accelerators,
-            IamInstanceProfile={"Arn": iam_profile_arn} if iam_profile_arn else None,
+            IamInstanceProfile={"Arn": iam_instance_profile_arn}
+            if iam_instance_profile_arn
+            else None,
             KeyName=key_name,
             InstanceMarketOptions=instance_market_options,
             CreditSpecification=credit_specifications or None,
@@ -906,7 +975,7 @@ async def present(
         result["force_save"] = True
 
         present_ret = await hub.tool.aws.ec2.instance.state.convert_to_present(
-            ctx, {"Reservations": [create_ret.ret]}
+            ctx, {"Reservations": [create_ret.ret]}, name=name
         )
         current_state = present_ret[resource_id]
 
@@ -917,25 +986,12 @@ async def present(
         result["result"] = False
         return result
 
-    # If no attributes need modification, then return right away
-    desired_state = hub.states.aws.ec2.instance.pre_process_desired_state(
-        chunk=desired_state
-    )
-
-    if all(
-        current_state.get(attribute) == new_value
-        for attribute, new_value in desired_state.items()
-        if attribute != "network_interfaces" and new_value is not None
-    ):
-        result["new_state"] = current_state
-        return result
-
     # Modify all the attributes that need modification
     if ctx.test:
         result["new_state"] = hub.tool.aws.ec2.instance.state.test(**desired_state)
     else:
         resource = await hub.tool.boto3.resource.create(
-            ctx, "ec2", "Instance", resource_id
+            ctx, "ec2", "Instance", id=resource_id
         )
         hub.log.debug(f"Waiting for instance '{resource.id}' to be created")
         try:
@@ -950,20 +1006,16 @@ async def present(
             comments=result["comment"],
         )
 
-        get = await hub.exec.aws.ec2.instance.get(ctx, resource_id=resource_id)
+        get = await hub.exec.aws.ec2.instance.get(
+            ctx, resource_id=resource_id, name=name
+        )
         result["new_state"] = get.ret
 
-    # Report successful bootstrapping methods
-    # TODO remove this once bootstrapping can be detected with heist
-    result["new_state"]["bootstrap"] = [
-        bootstrap_options["heist_manager"]
-        for bootstrap_options in desired_state.get("boostrap", ())
-    ]
     return result
 
 
 async def absent(
-    hub, ctx, name: str, resource_id: str = None, **kwargs
+    hub, ctx, name: str, resource_id: str = None, client_token: str = None, **kwargs
 ) -> Dict[str, Any]:
     """Shuts down the specified instance.
 
@@ -972,6 +1024,7 @@ async def absent(
     Args:
         name(str): The name of the state.
         resource_id(str): An instance id.
+        client_token(str): An idempotence token that was used with the instance creation
 
     Request Syntax:
         .. code-block:: sls
@@ -995,13 +1048,16 @@ async def absent(
         comment=[], old_state=ctx.old_state, new_state=None, name=name, result=True
     )
 
-    for key in kwargs:
-        result["comment"] += [f"Not explicitly supported keyword argument: '{key}'"]
-
     # Get the resource_id from ESM
     if not resource_id:
         resource_id = (ctx.old_state or {}).get("resource_id")
 
+    if not resource_id and client_token:
+        get = await hub.exec.aws.ec2.instance.get(
+            ctx, name=name, filters=[{"Name": "client-token", "Values": [client_token]}]
+        )
+        resource_id = get.ret.resource_id
+
     # If there still is no resource_id, the instance is gone
     if not resource_id:
         result["comment"] += [f"'{name}' already terminated"]
@@ -1014,20 +1070,24 @@ async def absent(
     ret = await hub.exec.boto3.client.ec2.terminate_instances(
         ctx, InstanceIds=[resource_id]
     )
-    result["result"] &= ret["result"]
-    if not result["result"]:
-        result["comment"].append(ret["comment"])
-        return result
-    result["comment"] += [
-        f"Terminated instance '{name}', it will still be visible for about 60 minutes"
-    ]
+    if ret.comment:
+        result["comment"].append(ret.comment)
 
+    if not ret.result and any("does not exist" in c for c in ret.comment):
+        # The command failed because the instance no longer exists
+        return result
+    elif not ret.result:
+        # The failure is some other reason we need to examine
+        result["result"] &= ret.result
+    else:
+        result["comment"] += [
+            f"Terminated instance '{name}', it will still be visible for about 60 minutes"
+        ]
     return result
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    """
-    Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns:
         Dict[str, Any]
@@ -1052,12 +1112,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-def pre_process_desired_state(hub, chunk):
-    desired_state = copy.deepcopy(chunk)
-    if desired_state.get("user_data"):
-        user_data = desired_state["user_data"]
-        desired_state["user_data"] = base64.b64encode(user_data.encode()).decode()
-
-    return desired_state
