@@ -401,97 +401,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             ]
         }
     return result
-
-
-async def search(hub, ctx, name, resource_id: str = None, filters: List = None):
-    """
-    Provides details about a specific route table as a data-source. Supply one of the inputs as the filter.
-    This function has been deprecated. Please use exec.run with aws.ec2.route_table.get instead.
-
-    Args:
-        name(str):
-            An Idem name of the AWS route table resource.
-        resource_id(str, Optional):
-            AWS route table ID to identify the resource.
-        filters(list, Optional):
-            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_route_tables
-
-    Request Syntax:
-        .. code-block:: sls
-
-            [Idem-state-name]:
-              aws.ec2.route_table.search:
-                - name: 'string'
-                - resource_id: 'string'
-                - filters:
-                  - name: 'string'
-                    values: list
-                  - name: 'string'
-                    values: list
-
-    Response Syntax:
-        The following fields will be returned in the `new_state` of the response.
-
-        - name: 'string'
-        - resource_id: 'string'
-        - vpc_id: 'string'
-        - propagating_vgws: list
-        - tags: list
-        - routes: list
-        - associations: list
-
-    Examples:
-
-        .. code-block:: sls
-
-            idem-test-route-table-search:
-              aws.ec2.route_table.search:
-                - name: idem-test-route-table-search
-                - filters:
-                  - name: 'vpc-id'
-                    values: ["vpc-0ba2072e7101375ee"]
-                  - name: 'tag:Name'
-                    values: ["cluster01-eks-private-0"]
-
-        Sample response:
-
-            - name: 'idem-test-route-table-search'
-            - resource_id: 'rtb-05d27d2c959185162'
-            - vpc_id: 'vpc-0ba2072e7101375ee'
-            - propagating_vgws: []
-            - tags:
-                - Key: 'Name'
-                  Value: 'cluster01-eks-private-0'
-            - routes:
-                - DestinationCidrBlock: '10.170.0.0/16'
-                  GatewayId: 'local'
-                  Origin: 'CreateRouteTable'
-                  State: 'active'
-            - associations:
-                - Main: False
-                  RouteTableAssociationId: 'rtbassoc-009e17e6d53ddf889'
-                  RouteTableId: 'rtb-05d27d2c959185162'
-                  SubnetId: 'subnet-023a9ac1f67decab0'
-                  AssociationState:
-                    State: 'associated'
-
-    """
-    hub.log.warning(
-        f"aws.ec2.route_table.search '{name}' state has been deprecated. Please use exec.run with aws.ec2.route_table.get instead."
-    )
-
-    result = dict(comment=[], old_state=None, new_state=None, name=name, result=True)
-    ret = await hub.exec.aws.ec2.route_table.get(
-        ctx=ctx,
-        name=name,
-        resource_id=resource_id,
-        filters=filters,
-    )
-    result["result"] = ret["result"]
-    result["comment"] = ret["comment"]
-    if result["result"] and ret["ret"]:
-        result["old_state"] = ret["ret"]
-        # Populate both "old_state" and "new_state" with the same data
-        result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
