@@ -337,128 +337,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             ]
         }
     return result
-
-
-async def search(
-    hub,
-    ctx,
-    name,
-    filters: List = None,
-    resource_id: str = None,
-    vpc_id: str = None,
-    tags: List[Dict[str, Any]] or Dict[str, Any] = None,
-):
-    """
-    Provides details about a specific Security Group as a data-source. Supply one of the inputs as the filter.
-
-    Args:
-        name(str):
-             The name of the Idem state.
-
-        resource_id(str, Optional):
-            Security Group id to identify the resource.
-
-        filters(list, Optional):
-            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_security_groups
-
-        vpc_id(str, Optional):
-            Id of the VPC security group attached to.
-
-        tags(list or dict, Optional):
-            list of tags in the format of [{"Key": tag-key, "Value": tag-value}] or dict in the format of
-            {tag-key: tag-value} for security group.
-
-    Request Syntax:
-       .. code-block:: sls
-
-          [Idem-state-name]:
-            aws.ec2.security_group.search:
-              - name: 'string'
-              - resource_id: 'string'
-              - filters:
-                - name: 'string'
-                  values: 'list'
-                - name: 'string'
-                  values: 'list'
-              - vpc_id: 'string'
-              - tags:
-                 - Key: 'string'
-                   Value: 'string'
-
-    Examples:
-
-        .. code-block:: bash
-
-            idem-test-security-group-search:
-              aws.ec2.security_group.search:
-                - name: idem-test-security-group
-                - filters:
-                    - name: 'group-name'
-                      values: ["idem-test-security-group"]
-                - vpc_id: vpc-247e9a5d
-                - tags:
-                    - Key: Name
-                      Value: sg-name
-                    - Key: sg-tag-key-2
-                      Value: sg-tag-value-2
-
-
-    This function has been deprecated.  Please use exec.run with aws.ec2.security_group.get or
-    aws.ec2.security_group.list instead.
-    """
-    hub.log.warning(
-        f"aws.ec2.security_group.search '{name}' state has been deprecated. Please use exec.run with"
-        "aws.ec2.security_group.get or aws.ec2.security_group.list instead."
-    )
-
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-    syntax_validation = hub.tool.aws.search_utils.search_filter_syntax_validation(
-        filters=filters
-    )
-    if not syntax_validation["result"]:
-        result["comment"] = syntax_validation["comment"]
-        return result
-    boto3_filter = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
-        filters=filters
-    )
-    if isinstance(tags, Dict):
-        tags = hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags)
-    if tags:
-        for tag in tags:
-            boto3_filter.append({"Name": "tag:" + tag["Key"], "Values": [tag["Value"]]})
-    if vpc_id:
-        boto3_filter.append({"Name": "vpc-id", "Values": [vpc_id]})
-
-    security_groups_args = {}
-    if boto3_filter:
-        security_groups_args["Filters"] = boto3_filter
-    # Including None as GroupIds, throws ParamValidationError for describe_security_groups
-    if resource_id:
-        security_groups_args["GroupIds"] = [resource_id]
-
-    ret = await hub.exec.boto3.client.ec2.describe_security_groups(
-        ctx, **security_groups_args
-    )
-
-    if not ret["result"]:
-        result["result"] = False
-        result["comment"] = ret["comment"]
-        return result
-
-    if not ret["ret"]["SecurityGroups"]:
-        result["comment"] = (f"Unable to find aws.ec2.security_group '{name}'",)
-        return result
-
-    security_group = ret["ret"]["SecurityGroups"][0]
-    if len(ret["ret"]["SecurityGroups"]) > 1:
-        result["comment"] = (
-            f"More than one aws.ec2.security_group resource was found. Use resource {security_group.get('GroupId')}",
-        )
-    result["old_state"] = hub.tool.aws.ec2.conversion_utils.convert_raw_sg_to_present(
-        security_group
-    )
-
-    # Populate both "old_state" and "new_state" with the same data
-    result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
