@@ -29,16 +29,16 @@ async def present(
         name (str):
             An Idem name for the snapshot resource.
 
-        resource_id (str, optional):
-            AWS Snapshot snapshot_id.
-
-        volume_id (str, required):
+        volume_id (str):
             AWS Volume volume_id of the volume the snapshot is to be created from.
 
-        description (str, optional):
+        resource_id (str, Optional):
+            AWS Snapshot snapshot_id.
+
+        description (str, Optional):
             A description propagated to every snapshot specified by the instance. Defaults to None.
 
-        outpost_arn (str, optional):
+        outpost_arn (str, Optional):
             The Amazon Resource Name (ARN) of the Outpost on which to create the local snapshots.   To
             create snapshots from an instance in a Region, omit this parameter. The snapshots are created in
             the same Region as the instance.   To create snapshots from an instance on an Outpost and store
@@ -48,7 +48,7 @@ async def present(
             Outpost as the instance.   For more information, see  Create multi-volume local snapshots from
             instances on an Outpost in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
 
-        tags (dict, optional):
+        tags (dict, Optional):
             Dict in the format of ``{tag-key: tag-value}`` to associate with the Snapshot.
 
             * Key (str):
@@ -240,7 +240,7 @@ async def absent(hub, ctx, name: str, resource_id: str) -> Dict[str, Any]:
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Gets information about the AWS Snapshot(s)
