@@ -753,98 +753,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-async def search(hub, ctx, name: str, filters: List = None, resource_id: str = None):
-    """
-    Use an un-managed Instance as a data-source. Supply one of the inputs as the filter.
-
-    Args:
-        hub:
-        ctx:
-        name(str): The name of the Idem state.
-        resource_id(str, Optional): AWS VPC id to identify the resource.
-        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key.
-            A complete list of filters can be found at https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances
-
-    Request Syntax:
-        [Idem-state-name]:
-          aws.ec2.spot_instance_request.search:
-          - resource_id: 'Text'
-          - filters:
-            - name: 'string'
-              values: 'list'
-            - name: 'string'
-              values: 'list'
-
-        Examples:
-
-            my-unmanaged-spot_instance_request:
-              aws.ec2.spot_instance_request.search:
-                - resource_id: value
-
-    This function has been deprecated.  Please use exec.run with aws.ec2.spot_instance_request.get or
-    aws.ec2.spot_instance_request.list instead.
-    """
-    hub.log.warning(
-        f"aws.ec2.spot_instance_request.search '{name}' state has been deprecated. Please use exec.run with"
-        "aws.ec2.spot_instance_request.get or aws.ec2.spot_instance_request.list instead."
-    )
-    result = dict(
-        comment=[], old_state=ctx.old_state, new_state=None, name=name, result=True
-    )
-
-    # Get the resource_id from ESM if this resource used to be managed by "present"
-    if not resource_id:
-        resource_id = (ctx.old_state or {}).get("resource_id")
-
-    # Perform validation on the parameters
-    syntax_validation = hub.tool.aws.search_utils.search_filter_syntax_validation(
-        filters=filters
-    )
-    result["result"] &= syntax_validation["result"]
-    if not result["result"]:
-        result["comment"].append(syntax_validation["comment"])
-        return result
-
-    boto3_filter = hub.tool.aws.search_utils.convert_search_filter_to_boto3(
-        filters=filters
-    )
-
-    # Get all instances that match the given filters
-    ret = await hub.exec.boto3.client.ec2.describe_spot_instance_requests(
-        ctx,
-        Filters=boto3_filter,
-        SpotInstanceRequestIds=[resource_id] if resource_id else None,
-    )
-    result["result"] &= ret.result
-    if not ret:
-        result["comment"].append(ret.comment)
-        return result
-
-    # Convert the described instances to the present state format
-    spot_instance_requests = (
-        await hub.tool.aws.ec2.spot_instance_request.convert_to_present(ret.ret)
-    )
-
-    # Check for null results
-    if not spot_instance_requests:
-        result["result"] = False
-        result["comment"] += [
-            f"Unable to find an aws.ec2.spot_instance_request for '{name}' that matched the given filters"
-        ]
-        return result
-
-    # Get the first spot_instance_request from the results
-    spot_instance_request_id = next(iter(spot_instance_requests.keys()))
-
-    # Add a comment if there were multiple results
-    if len(spot_instance_requests) > 1:
-        result["comment"] += [
-            f"More than one aws.ec2.spot_instance_request resource was found. Use resource '{spot_instance_request_id}'"
-        ]
-
-    # Return both old_state and new_state together
-    result["new_state"] = spot_instance_requests[spot_instance_request_id]
-
-    return result
