@@ -41,7 +41,7 @@ async def present(
         )
     ] = None,
 ) -> Dict[str, Any]:
-    r"""Attaches the specified VPC to the specified transit gateway.
+    """Attaches the specified VPC to the specified transit gateway.
 
     If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that is already attached, the new VPC
     CIDR range is not propagated to the default propagation route table. To send VPC traffic to an attached transit gateway,
@@ -366,7 +366,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Describes one or more VPC attachments. By default, all VPC attachments are described. Alternatively, you can
