@@ -38,13 +38,13 @@ async def present(
         name (str):
             An Idem name of the volume resource.
 
-        resource_id (str, optional):
+        resource_id (str, Optional):
             The AWS volume_id of the Volume. Defaults to None.
 
         availability_zone (str):
             The Availability Zone in which to create the volume.
 
-        encrypted (bool, optional):
+        encrypted (bool, Optional):
             Indicates whether the volume should be encrypted. The effect of setting the encryption state to
             true depends on the volume origin (new or from a snapshot), starting encryption state,
             ownership, and whether encryption by default is enabled. For more information, see Encryption by
@@ -52,7 +52,7 @@ async def present(
             attached to instances that support Amazon EBS encryption. For more information, see Supported
             instance types. Defaults to None.
 
-        iops (int, optional):
+        iops (int, Optional):
             The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents
             the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the
             baseline performance of the volume and the rate at which the volume accumulates I/O credits for
@@ -62,7 +62,7 @@ async def present(
             32,000 IOPS. This parameter is required for io1 and io2 volumes. The default for gp3 volumes is
             3,000 IOPS. This parameter is not supported for gp2, st1, sc1, or standard volumes. Defaults to None.
 
-        kms_key_id (str, optional):
+        kms_key_id (str, Optional):
             The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If
             this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified,
             the encrypted state must be true. You can specify the KMS key using any of the following:   Key
@@ -73,37 +73,37 @@ async def present(
             KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the
             action can appear to complete, but eventually fails. Defaults to None.
 
-        outpost_arn (str, optional):
+        outpost_arn (str, Optional):
             The Amazon Resource Name (ARN) of the Outpost. Defaults to None.
 
-        size (int, optional):
+        size (int, Optional):
             The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you
             specify a snapshot, the default is the snapshot size. You can specify a volume size that is
             equal to or larger than the snapshot size. The following are the supported volumes sizes for
             each volume type:    gp2 and gp3: 1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384
             standard: 1-1,024. Defaults to None.
 
-        snapshot_id (str, optional):
+        snapshot_id (str, Optional):
             The snapshot from which to create the volume. You must specify either a snapshot ID or a volume
             size. Defaults to None.
 
-        volume_type (str, optional): ]
+        volume_type (str, Optional): ]
             The volume type. This parameter can be one of the following values:   General Purpose SSD: gp2 |
             gp3    Provisioned IOPS SSD: io1 | io2    Throughput Optimized HDD: st1    Cold HDD: sc1
             Magnetic: standard    For more information, see Amazon EBS volume types in the Amazon Elastic
             Compute Cloud User Guide. Default: gp2. Defaults to None.
 
-        multi_attach_enabled (bool, optional):
+        multi_attach_enabled (bool, Optional):
             Indicates whether to enable Amazon EBS Multi-Attach. If you enable Multi-Attach, you can attach
             the volume to up to 16 Instances built on the Nitro System in the same Availability Zone. This
             parameter is supported with io1 and io2 volumes only. For more information, see  Amazon EBS
             Multi-Attach in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
 
-        throughput (int, optional):
+        throughput (int, Optional):
             The throughput to provision for a volume, with a maximum of 1,000 MiB/s. This parameter is valid
             only for gp3 volumes. Valid Range: Minimum value of 125. Maximum value of 1000. Defaults to None.
 
-        tags (dict, optional):
+        tags (dict, Optional):
             dict in the format of ``{tag-key: tag-value}``. Defaults to None.
 
             * Key (str):
@@ -304,7 +304,7 @@ async def absent(hub, ctx, name: str, resource_id: str) -> Dict[str, Any]:
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Describes the specified EBS volumes or all of your EBS volumes. If you are describing a long list of volumes, we
