@@ -12,6 +12,7 @@ async def present(
     name: str,
     resource_id: str,
     connection_status: str = None,
+    tags: Dict[str, str] = None,
 ) -> Dict[str, Any]:
     """Requests to modify the VPC peering connection accepter.
 
@@ -34,6 +35,10 @@ async def present(
             The desired status for the VPC peering connection, but in practice,
             an update will be attempted only if this status is set to "active".
 
+        tags(Dict, Optional):
+            Dict in the format of {tag-key: tag-value} The tags to assign to the peering connection.
+            Each tag consists of a key name and an associated value. Defaults to None.
+
     Request Syntax:
         .. code-block:: sls
 
@@ -41,6 +46,7 @@ async def present(
               aws.ec2.vpc_peering_connection_accepter.present:
                 - resource_id: "string"
                 - connection_status: "string"
+                - tags: "Dict"
 
     Returns:
         Dict[str, Any]
@@ -52,6 +58,11 @@ async def present(
               aws.ec2.vpc_peering_connection_accepter.present:
                 - resource_id: pcx-ae89ce9b
                 - connection_status: "active"
+                - tags:
+                    first_key: first_value
+                    second_key: second_value
+                    third_key: third_value
+                    fourth_key: fourth_value
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     resource_updated = False
@@ -94,12 +105,12 @@ async def present(
                 connection_status,
             )
 
-        result["result"] = accept_ret["result"]
-        result["comment"] += accept_ret["comment"]
-        if not accept_ret["result"]:
-            return result
+            result["result"] = accept_ret["result"]
+            result["comment"] += accept_ret["comment"]
+            if not accept_ret["result"]:
+                return result
 
-        resource_updated = resource_updated or bool(accept_ret["ret"])
+            resource_updated = resource_updated or bool(accept_ret["ret"])
 
         if resource_updated and ctx.get("test", False):
             plan_state["connection_status"] = accept_ret["ret"]["connection_status"]
@@ -118,6 +129,24 @@ async def present(
                 "aws.ec2.vpc_peering_connection_accepter", name
             )
 
+        # Update tags
+        if tags is not None and tags != result["old_state"].get("tags"):
+            update_ret = await hub.tool.aws.ec2.tag.update_tags(
+                ctx=ctx,
+                resource_id=resource_id,
+                old_tags=result["old_state"].get("tags"),
+                new_tags=tags,
+            )
+
+            result["result"] = update_ret["result"]
+            result["comment"] += update_ret["comment"]
+            if not update_ret["result"]:
+                return result
+
+            resource_updated = resource_updated or bool(update_ret["ret"])
+            if update_ret["ret"] is not None and ctx.get("test", False):
+                plan_state["tags"] = update_ret["ret"]
+
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not result["old_state"]) or resource_updated:
