@@ -663,134 +663,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             ]
         }
     return result
-
-
-async def search(hub, ctx, name, resource_id: str = None):
-    """Provides details about a specific Cluster.
-
-    Args:
-        name(str):
-             An Idem name of the EKS cluster resource.
-
-        resource_id(str, Optional):
-            AWS EKS cluster name to identify the resource.
-
-
-    Request Syntax:
-        [Idem-state-name]:
-          aws.eks.cluster.search:
-              - name: 'string'
-              - resource_id: 'string'
-
-    Response Syntax:
-        The following fields will be returned in the `new_state` of the response.
-
-        - name: 'string'
-        - resource_id: 'string'
-        - role_arn: 'string'
-        - arn: 'string'
-        - status: 'string'
-        - version: 'string'
-        - resources_vpc_config:
-            clusterSecurityGroupId: 'string'
-            endpointPrivateAccess: boolean
-            endpointPublicAccess: boolean
-            publicAccessCidrs:
-            - 'string'
-            securityGroupIds: list
-            subnetIds:
-            - 'string'
-            - 'string'
-            vpcId: 'string'
-        - kubernetes_network_config:
-            ipFamily: 'string'
-            serviceIpv4Cidr: 'string'
-        - logging:
-            clusterLogging:
-            - enabled: boolean
-              types:
-              - 'string'
-              - 'string'
-              - 'string'
-              - 'string'
-        - tags:
-            'string': 'string'
-        - oidc_identity_issuer: 'string'
-        - endpoint: 'string'
-        - certificate_authority:
-            data: 'string'
-
-    Examples:
-
-        Input state file:
-
-        .. code-block:: bash
-
-            idem-test-cluster-search:
-                aws.eks.cluster.search:
-                  - name: idem-test-cluster-search
-                  - resource_id: cluster-1
-
-        Sample response:
-
-            - name: cluster-1
-            - resource_id: cluster-1
-            - role_arn: arn:aws:iam::598227425989:role/eksClusterRole
-            - arn: arn:aws:eks:us-west-2:598227425989:cluster/cluster01
-            - status: ACTIVE
-            - version: '1.21'
-            - resources_vpc_config:
-                clusterSecurityGroupId: sg-0e364c2e68739a515
-                endpointPrivateAccess: false
-                endpointPublicAccess: true
-                publicAccessCidrs:
-                - 0.0.0.0/0
-                securityGroupIds: []
-                subnetIds:
-                - subnet-0f08315b4e261dd70
-                - subnet-0a8bfb7b1298755e0
-                vpcId: vpc-06ad93e0c4ccdf8b3
-            - kubernetes_network_config:
-                ipFamily: ipv4
-                serviceIpv4Cidr: 172.20.0.0/16
-            - logging:
-                clusterLogging:
-                - enabled: false
-                  types:
-                  - api
-                  - audit
-                  - authenticator
-                  - controllerManager
-                  - scheduler
-            - tags:
-                Name: cluster-1
-            - oidc_identity_issuer: https://oidc.eks.us-west-2.amazonaws.com/id/4E0FCBD1CFBD5DD3C662D0AED6514340
-            - endpoint: https://4E0FCBD1CFBD5DD3C662D0AED6514340.sk1.us-west-2.eks.amazonaws.com
-            - certificate_authority:
-                data: LS0tLjdExMNgpnQU5GQmtOYk5tUWxoaUkyZmg0dzB2SGVUTlN4MkNnYk5VN29mTEt4cmxNNjhvZ0YyXZUOEQ3TDEvaHhQQW9YMzZ6lyCjBEcDRvb
-
-
-    """
-    hub.log.warning(
-        f"aws.eks.cluster.search '{name}' state has been deprecated. Please use exec.run with aws.eks.cluster.get instead."
-    )
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-
-    ret = await hub.exec.boto3.client.eks.describe_cluster(ctx, name=resource_id)
-
-    if not ret["result"]:
-        result["result"] = False
-        result["comment"] = ret["comment"]
-        return result
-
-    cluster = ret["ret"].get("cluster")
-    translated_resource = (
-        hub.tool.aws.eks.conversion_utils.convert_raw_cluster_to_present(
-            raw_resource=cluster, idem_resource_name=name
-        )
-    )
-
-    result["old_state"] = translated_resource
-    # Populate both "old_state" and "new_state" with the same data
-    result["new_state"] = copy.deepcopy(result["old_state"])
-    return result
