@@ -25,7 +25,7 @@ async def present(
         )
     ] = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Creates an IAM entity to describe an identity provider (IdP) that supports OpenID Connect (OIDC).
 
     The OIDC provider that you create with this operation can be used as a principal in a role's trust policy.
@@ -45,9 +45,9 @@ async def present(
     You get all of this information from the OIDC IdP you want to use to access Amazon Web Services.
 
     Args:
-        name(Text): The idem name for IAM OIDC provider.
+        name(str): The idem name for IAM OIDC provider.
 
-        url(Text): The URL of the identity provider. The URL must begin with https:// and should correspond to the iss
+        url(str): The URL of the identity provider. The URL must begin with https:// and should correspond to the iss
             claim in the provider's OpenID Connect ID tokens. Per the OIDC standard, path components are allowed but
             query parameters are not. Typically the URL consists of only a hostname, like https://server.example.org or
             https://example.com . The URL should not contain a port number.
@@ -72,16 +72,16 @@ async def present(
             For more information about obtaining the OIDC provider thumbprint, see Obtaining the thumbprint for an
             OpenID Connect provider in the IAM User Guide .
 
-            (string) --
+            (str) --
                 Contains a thumbprint for an identity provider's server certificate.
 
                 The identity provider's server certificate thumbprint is the hex-encoded SHA-1 hash value of the
                 self-signed X.509 certificate. This thumbprint is used by the domain where the OpenID Connect provider
                 makes its keys available. The thumbprint is always a 40-character string.
 
-        resource_id(Text, optional): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object.
+        resource_id(str, Optional): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object.
 
-        client_id_list(List, optional): Provides a list of client IDs, also known as audiences. When a mobile or web
+        client_id_list(List, Optional): Provides a list of client IDs, also known as audiences. When a mobile or web
             app registers with an OpenID Connect provider, they establish a value that identifies the application. This
             is the value that's sent as the client_id parameter on OAuth requests.
 
@@ -92,7 +92,7 @@ async def present(
             There is no defined format for a client ID. The CreateOpenIDConnectProviderRequest operation accepts
             client IDs up to 255 characters long.
 
-        tags(Dict or List, optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
+        tags(Dict or List, Optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
             [{"Key": tag-key, "Value": tag-value}] to associate with the IAM OpenID Connect (OIDC) provider.
             Each tag consists of a key name and an associated value. Defaults to None.
             * (Key): The key name that can be used to look up or retrieve the associated value. For example,
@@ -299,8 +299,8 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     trust policies. Any attempt to assume a role that references a deleted provider fails.
 
     Args:
-        name(Text): The idem name for IAM OIDC provider.
-        resource_id(Text): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object to delete.
+        name(str): The idem name for IAM OIDC provider.
+        resource_id(str): The Amazon Resource Name (ARN) of the IAM OpenID Connect provider resource object to delete.
 
     Request Syntax:
         [oidc-resource-id]:
@@ -366,7 +366,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Gets information about the AWS IAM OpenID Connect provider
