@@ -23,7 +23,7 @@ async def present(
     """Attaches a policy to a root, an organizational unit (OU), or an individual account.
 
     How the policy affects accounts depends on the type of policy. The only supported policy types are
-    ``SERVICE_CONTROL_POLICY`` and ``TAG_POLICY``.
+    ``SERVICE_CONTROL_POLICY``, ``AISERVICES_OPT_OUT_POLICY``, ``TAG_POLICY`` and ``BACKUP_POLICY``.
 
     Args:
         name(str):
@@ -194,7 +194,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     This operation can be called only from the organization's management account
     or by a member account that is a delegated administrator for an AWS service.
 
-    The only supported policy types are ``SERVICE_CONTROL_POLICY`` and ``TAG_POLICY``.
+    The supported policy types are ``SERVICE_CONTROL_POLICY``, ``TAG_POLICY``, ``AISERVICES_OPT_OUT_POLICY`` and ``BACKUP_POLICY``.
 
     Returns:
         Dict[str, Dict[str, Any]
@@ -204,33 +204,34 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
             $ idem describe aws.organizations.policy_attachment
     """
+
     result = {}
+    list_all_policies = []
+    filters = [
+        "SERVICE_CONTROL_POLICY",
+        "TAG_POLICY",
+        "BACKUP_POLICY",
+        "AISERVICES_OPT_OUT_POLICY",
+    ]
 
-    ret = await hub.exec.boto3.client.organizations.list_policies(
-        ctx, Filter="SERVICE_CONTROL_POLICY"
-    )
+    for filter in filters:
 
-    if not ret or not ret["ret"]:
-        hub.log.debug(f"Could not describe policy_attachments {ret['comment']}")
-        return result
-
-    all_policies = ret["ret"].get("Policies", [])
-
-    list_tag_policies = await hub.exec.boto3.client.organizations.list_policies(
-        ctx, Filter="TAG_POLICY"
-    )
-    if not list_tag_policies:
-        hub.log.debug(
-            f"Could not describe policy_attachments {list_tag_policies['comment']}"
+        list_policies = await hub.exec.boto3.client.organizations.list_policies(
+            ctx, Filter=filter
         )
-        return {}
 
-    if list_tag_policies["ret"]["Policies"]:
-        all_policies.extend(list_tag_policies["ret"]["Policies"])
+        if not list_policies:
+            hub.log.debug(
+                f"Could not describe policy with error: {list_policies['comment']}"
+            )
+            return {}
 
-    if all_policies:
+        if list_policies["ret"]["Policies"]:
+            list_all_policies.extend(list_policies["ret"]["Policies"])
 
-        for policy in all_policies:
+    if list_all_policies:
+
+        for policy in list_all_policies:
 
             policy_attachments_ret = (
                 await hub.exec.boto3.client.organizations.list_targets_for_policy(
