@@ -1072,7 +1072,7 @@ async def absent(
     final_db_snapshot_identifier: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""The DeleteDBCluster action deletes a previously provisioned DB cluster.
+    """The DeleteDBCluster action deletes a previously provisioned DB cluster.
 
     When you delete a DB cluster, all automated backups for that DB cluster are deleted and can't be recovered. Manual
     DB cluster snapshots of the specified DB cluster are not deleted. For more information on Amazon Aurora, see
@@ -1189,7 +1189,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns information about Amazon Aurora DB clusters and Multi-AZ DB clusters. This API supports pagination. For
     more information on Amazon Aurora DB clusters, see  What is Amazon Aurora? in the Amazon Aurora User Guide.  For
