@@ -115,125 +115,126 @@ async def present(
     Creates a new DB instance.
 
     Args:
-        hub:
-        ctx:
-        name(Text): Idem name to identify the resource.
+        name(str): Idem name to identify the resource.
         allocated_storage(int): The amount of storage in gibibytes (GiB) to allocate for the DB instance
-        db_instance_class(Text): The compute and memory capacity of the DB instance, for example db.m4.large
-        engine(Text): The name of the database engine to be used for this instance.
-        resource_id(Text, optional): AWS Id of the resource
-        db_name(Text, optional): Name of the database
-        master_username(Text, optional): The name for the master user.Not required for aurora
-        master_user_password(Text, optional): The password for the master user. The password can include any printable
-                                             ASCII character except "/", """, or "@".Not required for aurora
-        db_security_groups(list, optional): A list of DB security groups to associate with this DB instance.
-        vpc_security_group_ids(list, optional): A list of DB security groups to associate with this DB instance.
-        availability_zone(Text, optional): The Availability Zone (AZ) where the database will be created.
-        db_subnet_group_name(Text, optional): A DB subnet group to associate with this DB instance.
-        preferred_maintenance_window(Text, optional): The time range each week during which system maintenance can occur,
-                                                     in Universal Coordinated Time (UTC).
-        db_parameter_group_name(Text, optional): The name of the DB parameter group to associate with this DB instance.
-                                                If you do not specify a value,then the default DB parameter group for
-                                                the specified DB engine and version is used.
-        backup_retention_period(int, optional): The number of days for which automated backups are retained. Setting
-                                                this parameter to a positive number enables backups. Setting this
-                                                parameter to 0 disables automated backups.
-        preferred_backup_window(Text, optional): The daily time range during which automated backups are created if
-                                                automated backups are enabled,using the BackupRetentionPeriod parameter.
-        port(int, optional): The port number on which the database accepts connections.
-        multi_az(bool, optional): A value that indicates whether the DB instance is a Multi-AZ deployment. You can't set
-                                  the AvailabilityZone parameter if the DB instance is a Multi-AZ deployment.
-        engine_version(Text, optional): The version number of the database engine to use.
-        auto_minor_version_upgrade(bool, optional): A value that indicates whether minor engine upgrades are applied
-                                                    automatically to the DB instance during the maintenance window. By
-                                                    default, minor engine upgrades are applied automatically.
-        license_model(Text, optional): License model information for this DB instance.
-        iops(int, optional): The amount of Provisioned IOPS (input/output operations per second) to be initially
-                             allocated for the DB instance.
-        option_group_name(Text, optional): A value that indicates that the DB instance should be associated with the
-                                          specified option group.
-        character_set_name(Text, optional): For supported engines, this value indicates that the DB instance should be
-                                           associated with the specified CharacterSet .
-        nchar_character_set_name(Text, optional): The name of the NCHAR character set for the Oracle DB instance.
-        publicly_accessible(bool, optional): A value that indicates whether the DB instance is publicly accessible.
-        tags(Dict or List, optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
-            [{"Key": tag-key, "Value": tag-value}] to associate with the DB instance.
+        db_instance_class(str): The compute and memory capacity of the DB instance, for example db.m4.large
+        engine(str): The name of the database engine to be used for this instance.
+        resource_id(str, Optional): AWS Id of the resource
+        db_name(str, Optional): Name of the database
+        master_username(str, Optional): The name for the master user.Not required for aurora
+        master_user_password(str, Optional): The password for the master user. The password can include any printable
+            ASCII character except "/", """, or "@".Not required for aurora
+        db_security_groups(list, Optional): A list of DB security groups to associate with this DB instance.
+        vpc_security_group_ids(list, Optional): A list of DB security groups to associate with this DB instance.
+        availability_zone(str, Optional): The Availability Zone (AZ) where the database will be created.
+        db_subnet_group_name(str, Optional): A DB subnet group to associate with this DB instance.
+        preferred_maintenance_window(str, Optional): The time range each week during which system maintenance can occur,
+            in Universal Coordinated Time (UTC).
+        db_parameter_group_name(str, Optional): The name of the DB parameter group to associate with this DB instance.
+            If you do not specify a value,then the default DB parameter group for
+            the specified DB engine and version is used.
+        backup_retention_period(int, Optional): The number of days for which automated backups are retained. Setting
+            this parameter to a positive number enables backups. Setting this
+            parameter to 0 disables automated backups.
+        preferred_backup_window(str, Optional): The daily time range during which automated backups are created if
+            automated backups are enabled,using the BackupRetentionPeriod parameter.
+        port(int, Optional): The port number on which the database accepts connections.
+        multi_az(bool, Optional): A value that indicates whether the DB instance is a Multi-AZ deployment. You can't set
+            the AvailabilityZone parameter if the DB instance is a Multi-AZ deployment.
+        engine_version(str, Optional): The version number of the database engine to use.
+        auto_minor_version_upgrade(bool, Optional): A value that indicates whether minor engine upgrades are applied
+            automatically to the DB instance during the maintenance window. By
+            default, minor engine upgrades are applied automatically.
+        license_model(str, Optional): License model information for this DB instance.
+        iops(int, Optional): The amount of Provisioned IOPS (input/output operations per second) to be initially
+            allocated for the DB instance.
+        option_group_name(str, Optional): A value that indicates that the DB instance should be associated with the
+            specified option group.
+        character_set_name(str, Optional): For supported engines, this value indicates that the DB instance should be
+            associated with the specified CharacterSet .
+        nchar_character_set_name(str, Optional): The name of the NCHAR character set for the Oracle DB instance.
+        publicly_accessible(bool, Optional): A value that indicates whether the DB instance is publicly accessible.
+        tags(Dict or List, Optional): Dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
+            ``[{"Key": tag-key, "Value": tag-value}]`` to associate with the DB instance.
             Each tag consists of a key name and an associated value. Defaults to None.
-            * Key (str, optional): The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode
-                characters. May not begin with aws:.
-            * Value(str, optional): The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 256
-                Unicode characters.
-        db_cluster_identifier(Text, optional): The identifier of the DB cluster that the instance will belong to.
-        storage_type(Text, optional): Specifies the storage type to be associated with the DB instance.
-        tde_credential_arn(Text, optional): The ARN from the key store with which to associate the instance for TDE
-                                           encryption.
-        tde_credential_password(Text, optional): The password for the given ARN from the key store in order to access the
-                                                device.
-        storage_encrypted(bool, optional): A value that indicates whether the DB instance is encrypted. By default, it
-                                           isn't encrypted
-        kms_key_id(Text, optional): The Amazon Web Services KMS key identifier for an encrypted DB instance.
-        domain(Text, optional): The Active Directory, directory ID to create the DB instance in
-        copy_tags_to_snapshot(Text, optional): A value that indicates whether to copy tags from the DB instance to
-                                              snapshots of the DB instance. By default, tags are not copied.
-        monitoring_interval(int, optional): The interval, in seconds, between points when Enhanced Monitoring metrics
-                                            are collected for the DB instance.To disable collection of Enhanced
-                                            Monitoring metrics, specify 0. The default is 0.
-                                            If MonitoringRoleArn is specified, then you must set MonitoringInterval to
-                                            a value other than 0.
-        monitoring_role_arn(Text, optional): The ARN for the IAM role that permits RDS to send enhanced monitoring metrics
-                                            to Amazon CloudWatch Logs.
-        domain_iam_role_name(Text, optional): Specify the name of the IAM role to be used when making API calls to the
-                                             Directory Service.
-        promotion_tier(int, optional): A value that specifies the order in which an Aurora Replica is promoted to the
-                                       primary instance after a failure of the existing primary instance.
-        timezone(Text, optional): The time zone of the DB instance.
-        enable_iam_database_authentication(bool, optional): A value that indicates whether to enable mapping of Amazon
-                                                            Web Services Identity and Access Management (IAM) accounts
-                                                            to database accounts. By default, mapping isn't enabled.
-        enable_performance_insights(bool, optional): A value that indicates whether to enable Performance Insights for the DB instance.
-        performance_insights_kms_key_id(Text, optional): The Amazon Web Services KMS key identifier for encryption of
-                                                        Performance Insights data.
-        performance_insights_retention_period(int, optional): The amount of time, in days, to retain Performance
-                                                              Insights data.
-        enable_cloudwatch_logs_exports(List, optional):The list of log types that need to be enabled for exporting to
-                                                       CloudWatch Logs. The values in the list depend on the DB engine.
-        processor_features(List[Dict[str, Any]], optional): The number of CPU cores and the number of threads per core for the DB instance class of the DB
-            instance. This setting doesn't apply to RDS Custom. Defaults to None.
-            * Name (str, optional): The name of the processor feature. Valid names are coreCount and threadsPerCore.
-            * Value (str, optional): The value of a processor feature name.
-        deletion_protection(bool, optional):A value that indicates whether the DB instance has deletion protection
-                                            enabled. The database can't be deleted when deletion protection is enabled.
-                                            By default, deletion protection isn't enabled.
-        max_allocated_storage(int, optional): The upper limit in gigabytes (GiB) to which Amazon RDS can automatically
-                                              scale the storage of the DB instance.
-        enable_customer_owned_ip(bool, optional): A value that indicates whether to enable a customer-owned IP address
-                                                  (CoIP) for an RDS on Outposts DB instance.
-        custom_iam_instance_profile(Text, optional): The instance profile associated with the underlying Amazon EC2
-                                                    instance of an RDS Custom DB instance.
-        backup_target(Text, optional):  Value to specify where automated backups and manual snapshots are stored.
 
-        # parameters for the modify function
-        apply_immediately(bool, optional): A value that indicates whether the modifications in this request and any
-                                           pending modifications are asynchronously applied as soon as possible,
-                                           regardless of the PreferredMaintenanceWindow setting for the DB instance.
-                                           By default, this parameter is disabled.
-        allow_major_version_upgrades(bool, optional): A value that indicates whether major version upgrades are allowed.
-                                                      Changing this parameter doesn't result in an outage and the change
-                                                      is asynchronously applied as soon as possible.
-        cloudwatch_logs_export_configuration(Dict, optional): The configuration setting for the log types to be enabled
-                                                              for export to CloudWatch Logs for a specific DB instance.
-        ca_certificate_identifier(Text, optional): The identifier of the CA certificate for the DB instance.
-        use_default_processor_features(bool, optional): A value that indicates whether the DB instance class of the DB
-                                                        instance uses its default processor features.
-        certificate_rotation_restart(bool, optional): A value that indicates whether the DB instance is restarted when
-                                                      you rotate your SSL/TLS certificate.
-        replica_mode(Text, optional):A value that sets the open mode of a replica database to either mounted or read-only
-        aws_backup_recovery_point_arn(Text, optional): The Amazon Resource Name (ARN) of the recovery point in Amazon Web
-                                                      Services Backup.
-        automation_mode(Text, optional): The automation mode of the RDS Custom DB instance: full or all paused .
-        resume_full_automation_mode_minutes(int, optional):The number of minutes to pause the automation. When the time
-                                                            period ends, RDS Custom resumes full automation
-        timeout(Dict, optional): Timeout configuration for create/update of AWS DB Cluster.
+            * Key (str, Optional): The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode
+                characters. May not begin with aws:.
+            * Value(str, Optional): The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 256
+                Unicode characters.
+
+        db_cluster_identifier(str, Optional): The identifier of the DB cluster that the instance will belong to.
+        storage_type(str, Optional): Specifies the storage type to be associated with the DB instance.
+        tde_credential_arn(str, Optional): The ARN from the key store with which to associate the instance for TDE
+            encryption.
+        tde_credential_password(str, Optional): The password for the given ARN from the key store in order to access the
+            device.
+        storage_encrypted(bool, Optional): A value that indicates whether the DB instance is encrypted. By default, it
+            isn't encrypted
+        kms_key_id(str, Optional): The Amazon Web Services KMS key identifier for an encrypted DB instance.
+        domain(str, Optional): The Active Directory, directory ID to create the DB instance in
+        copy_tags_to_snapshot(str, Optional): A value that indicates whether to copy tags from the DB instance to
+            snapshots of the DB instance. By default, tags are not copied.
+        monitoring_interval(int, Optional): The interval, in seconds, between points when Enhanced Monitoring metrics
+            are collected for the DB instance.To disable collection of Enhanced
+            Monitoring metrics, specify 0. The default is 0.
+            If MonitoringRoleArn is specified, then you must set MonitoringInterval to
+            a value other than 0.
+        monitoring_role_arn(str, Optional): The ARN for the IAM role that permits RDS to send enhanced monitoring metrics
+            to Amazon CloudWatch Logs.
+        domain_iam_role_name(str, Optional): Specify the name of the IAM role to be used when making API calls to the
+            Directory Service.
+        promotion_tier(int, Optional): A value that specifies the order in which an Aurora Replica is promoted to the
+            primary instance after a failure of the existing primary instance.
+        timezone(str, Optional): The time zone of the DB instance.
+        enable_iam_database_authentication(bool, Optional): A value that indicates whether to enable mapping of Amazon
+            Web Services Identity and Access Management (IAM) accounts
+            to database accounts. By default, mapping isn't enabled.
+        enable_performance_insights(bool, Optional): A value that indicates whether to enable Performance Insights for the DB instance.
+        performance_insights_kms_key_id(str, Optional): The Amazon Web Services KMS key identifier for encryption of
+            Performance Insights data.
+        performance_insights_retention_period(int, Optional): The amount of time, in days, to retain Performance
+            Insights data.
+        enable_cloudwatch_logs_exports(List, Optional):The list of log types that need to be enabled for exporting to
+            CloudWatch Logs. The values in the list depend on the DB engine.
+        processor_features(List[Dict[str, Any]], Optional): The number of CPU cores and the number of threads per core for the DB instance class of the DB
+            instance. This setting doesn't apply to RDS Custom. Defaults to None.
+
+            * Name (str, Optional): The name of the processor feature. Valid names are coreCount and threadsPerCore.
+            * Value (str, Optional): The value of a processor feature name.
+
+        deletion_protection(bool, Optional):A value that indicates whether the DB instance has deletion protection
+            enabled. The database can't be deleted when deletion protection is enabled.
+            By default, deletion protection isn't enabled.
+        max_allocated_storage(int, Optional): The upper limit in gigabytes (GiB) to which Amazon RDS can automatically
+            scale the storage of the DB instance.
+        enable_customer_owned_ip(bool, Optional): A value that indicates whether to enable a customer-owned IP address
+            (CoIP) for an RDS on Outposts DB instance.
+        custom_iam_instance_profile(str, Optional): The instance profile associated with the underlying Amazon EC2
+            instance of an RDS Custom DB instance.
+        backup_target(str, Optional):  Value to specify where automated backups and manual snapshots are stored.
+        apply_immediately(bool, Optional): A value that indicates whether the modifications in this request and any
+            pending modifications are asynchronously applied as soon as possible,
+            regardless of the PreferredMaintenanceWindow setting for the DB instance.
+            By default, this parameter is disabled.
+        allow_major_version_upgrades(bool, Optional): A value that indicates whether major version upgrades are allowed.
+            Changing this parameter doesn't result in an outage and the change
+            is asynchronously applied as soon as possible.
+        cloudwatch_logs_export_configuration(Dict, Optional): The configuration setting for the log types to be enabled
+            for export to CloudWatch Logs for a specific DB instance.
+        ca_certificate_identifier(str, Optional): The identifier of the CA certificate for the DB instance.
+        use_default_processor_features(bool, Optional): A value that indicates whether the DB instance class of the DB
+            instance uses its default processor features.
+        certificate_rotation_restart(bool, Optional): A value that indicates whether the DB instance is restarted when
+            you rotate your SSL/TLS certificate.
+        replica_mode(str, Optional):A value that sets the open mode of a replica database to either mounted or read-only
+        aws_backup_recovery_point_arn(str, Optional): The Amazon Resource Name (ARN) of the recovery point in Amazon Web
+            Services Backup.
+        automation_mode(str, Optional): The automation mode of the RDS Custom DB instance: full or all paused .
+        resume_full_automation_mode_minutes(int, Optional):The number of minutes to pause the automation. When the time
+            period ends, RDS Custom resumes full automation
+        timeout(Dict, Optional): Timeout configuration for create/update of AWS DB Cluster.
+
             * create (Dict) -- Timeout configuration for creating DB Instance
                 * delay(int) -- The amount of time in seconds to wait between attempts.Defaults to 30
                 * max_attempts(int) -- Customized timeout configuration containing delay and max attempts.Defaults to 60
@@ -243,41 +244,42 @@ async def present(
 
 
     Request Syntax:
-        [db-instance-name]:
-          aws.rds.db_instance.present:
-          - db_instance_class: 'string'
-          - engine: 'string'
-          - resource_id: 'string'
-          - availability_zone: 'string'
-          - preferred_maintenance_window: 'string'
-          - multi_az: 'bool'
-          - engine_version: 'string'
-          - auto_minor_version_upgrade: 'bool'
-          - license_model: 'string'
-          - publicly_accessible: 'bool'
-          - db_cluster_identifier: 'string'
-          - storage_type: 'string'
-          - storage_encrypted: 'bool'
-          - copy_tags_to_snapshot: 'bool'
-          - monitoring_interval: 'int'
-          - monitoring_role_arn: 'string'
-          - promotion_tier: 'int'
-          - enable_performance_insights: 'bool'
-          - performance_insights_kms_key_id: 'string'
-          - performance_insights_retention_period: 'int'
-          - backup_target: 'string'
-          - vpc_security_group_id: 'List'
-          - db_subnet_group_name: 'string'
-          - db_parameter_group_name: 'string'
-          - option_group_name: 'string'
-          - tags: 'List'
-          - timeout: 'Dict'
+        .. code-block:: sls
+
+          [db-instance-name]:
+            aws.rds.db_instance.present:
+              - db_instance_class: 'string'
+              - engine: 'string'
+              - resource_id: 'string'
+              - availability_zone: 'string'
+              - preferred_maintenance_window: 'string'
+              - multi_az: 'bool'
+              - engine_version: 'string'
+              - auto_minor_version_upgrade: 'bool'
+              - license_model: 'string'
+              - publicly_accessible: 'bool'
+              - db_cluster_identifier: 'string'
+              - storage_type: 'string'
+              - storage_encrypted: 'bool'
+              - copy_tags_to_snapshot: 'bool'
+              - monitoring_interval: 'int'
+              - monitoring_role_arn: 'string'
+              - promotion_tier: 'int'
+              - enable_performance_insights: 'bool'
+              - performance_insights_kms_key_id: 'string'
+              - performance_insights_retention_period: 'int'
+              - backup_target: 'string'
+              - vpc_security_group_id: 'List'
+              - db_subnet_group_name: 'string'
+              - db_parameter_group_name: 'string'
+              - option_group_name: 'string'
+              - tags: 'List'
+              - timeout: 'Dict'
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
               instance-1:
@@ -316,7 +318,6 @@ async def present(
                       max_attempts: 30
 
     '''
-
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     params_to_modify = {}
     plan_state = None
@@ -639,7 +640,7 @@ async def absent(
     final_db_snapshot_identifier: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     **Autogenerated function**
 
     The DeleteDBInstance action deletes a previously provisioned DB instance. When you delete a DB instance, all
@@ -656,14 +657,13 @@ async def absent(
     promotion completes, then call the DeleteDBInstance API action to delete the final instance in the DB cluster.
 
     Args:
-        ctx:
-        hub:
-        name(Text): Idem name to identify the resource.
-        resource_id(Text): AWS ID to identify the resource.
-        skip_final_snapshot(bool, optional): Mention this true if you want to skip creating snapshot default is false.
-                                             Either this or final_db_snapshot_identifier should be provided
-        final_db_snapshot_identifier(Text, optional): Id for the created final db_snapshot while deleting
-        timeout(Dict, optional): Timeout configuration for deletion of AWS DB Instance.
+        name(str): Idem name to identify the resource.
+        resource_id(str): AWS ID to identify the resource.
+        skip_final_snapshot(bool, Optional): Mention this true if you want to skip creating snapshot default is false.
+            Either this or final_db_snapshot_identifier should be provided
+        final_db_snapshot_identifier(str, Optional): Id for the created final db_snapshot while deleting
+        timeout(Dict, Optional): Timeout configuration for deletion of AWS DB Instance.
+
             * delete (Dict) -- Timeout configuration for deletion of a DB Instance
                 * delay(int) -- The amount of time in seconds to wait between attempts.Defaults to 30
                 * max_attempts(int) -- Customized timeout configuration containing delay and max attempts.Defaults to 60
@@ -672,7 +672,6 @@ async def absent(
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
             test-db-instance:
@@ -680,7 +679,6 @@ async def absent(
                 - resource_id: test-db-instance,
                 - skip_final_snapshot: true
     """
-
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
 
     before = await hub.exec.boto3.client.rds.describe_db_instances(
@@ -746,7 +744,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     **Autogenerated function**
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function
@@ -760,7 +758,6 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: bash
 
             $ idem describe aws.rds.db_instance
