@@ -451,129 +451,3 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
-
-
-async def search(
-    hub,
-    ctx,
-    name: str,
-    hosted_zone_name: str = None,
-    resource_id: str = None,
-    private_zone: bool = None,
-    vpc_id: str = None,
-    tags: List = None,
-):
-    """
-    Use an un-managed hosted_zone as a data-source. Supply one or more of the inputs as the filter.
-    This function has been deprecated. Please use exec.run with aws.route53.hosted_zone.get instead.
-
-    Args:
-        name(str):
-            The name of the Idem state.
-
-        hosted_zone_name(str, Optional):
-            The domain name of hosted_zone
-
-        resource_id(str, Optional):
-            AWS hosted_zone id to filter the resource.If resource_id is mentioned then we directly return the resource
-            without checking other filters
-
-        private_zone(bool, Optional):
-            Bool argument to specify a private hosted_zone. One of the filter option for hosted_zone
-
-        vpc_id(str, Optional):
-            The vpc_id associated with the hosted_zone.One of the filter option for hosted_zone
-
-        tags(list, Optional):
-            Tags of the hosted_zone. One of the filter option for hosted_zone
-
-
-    Request Syntax:
-        .. code-block:: sls
-
-            [Idem-state-name]:
-              aws.route53.hosted_zone.search:
-                - hosted_zone_name: 'string'
-                - resource_id: 'string'
-                - private_zone: 'bool'
-                - vpc_id: 'string'
-                - tags: 'List'
-
-    Returns:
-        Dict[str, Any]
-
-    Examples:
-        .. code-block:: sls
-
-            my-unmanaged-hosted_zone:
-              aws.route53.hosted_zone.search:
-                - hosted_zone_name: idem-test-example-86a1d12e-4d68-4979-96ff-8608c33e4b9f.com.
-                - resource_id: Z02905093MT09M4X5AHR5
-                - private_zone: false
-                - vpc_id: vpc-0e87ce8f2c3317d53
-                - tags:
-                    - Key: Name
-                      Value: idem-test-hosted_zone
-
-    """
-
-    hub.log.warning(
-        f"aws.route53.hosted_zone.search '{name}' state has been deprecated. Please use exec.run with aws.route53.hosted_zone.get instead."
-    )
-    result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
-    if resource_id:
-        # If resource_id is mentioned directly returning the hosted_zone
-        ret = await hub.exec.aws.route53.hosted_zone.get(
-            ctx, name=name, resource_id=resource_id
-        )
-        if not ret["result"]:
-            result["result"] = ret["result"]
-            result["comment"] = (
-                f"Could not find hosted_zone with given {resource_id} resource_id {ret['comment']}",
-            )
-            return result
-        result["comment"] = (
-            f"Found hosted_zone with given resource_id {resource_id}, other filters will not be considered",
-        )
-        result["old_state"] = ret["ret"]
-        # Populate both "old_state" and "new_state" with the same data
-        result["new_state"] = copy.deepcopy(result["old_state"])
-    else:
-        # Get all the hosted_zones to apply the filters
-        describe_ret = (
-            await hub.tool.aws.route53.hosted_zone_utils.get_all_hosted_zones(ctx)
-        )
-        if not describe_ret["result"]:
-            result["result"] = False
-            result["comment"] = (
-                f"Could not describe all the aws.route53.hosted_zone resources to apply the filters, {describe_ret['comment']}",
-            )
-            return result
-
-        ret = hub.tool.aws.route53.hosted_zone_utils.get_hosted_zones_with_filters(
-            raw_hosted_zones=describe_ret["ret"],
-            hosted_zone_name=hosted_zone_name,
-            private_zone=private_zone,
-            vpc_id=vpc_id,
-            tags=tags,
-        )
-        result["comment"] = result["comment"] + ret["comment"]
-        if not ret["ret"]:
-            result["result"] = ret["result"]
-            return result
-
-        # For backward compatibility since search returns a single object
-        hosted_zone = ret["ret"][0]
-        tags = hosted_zone.get("tags")
-
-        result[
-            "old_state"
-        ] = hub.tool.aws.route53.conversion_utils.convert_raw_hosted_zone_to_present(
-            raw_resource=hosted_zone,
-            idem_resource_name=name,
-            tags=tags,
-        )
-        # Populate both "old_state" and "new_state" with the same data
-        result["new_state"] = copy.deepcopy(result["old_state"])
-
-    return result
