@@ -115,22 +115,24 @@ async def present(
                 Indicates whether this bucket has an Object Lock configuration enabled. Enable ObjectLockEnabled
                 when you apply ObjectLockConfiguration to a bucket.
             * Rule (dict):
-                Specifies the Object Lock rule for the specified object. Enable this rule when you apply ObjectLockConfiguration
-                to a bucket. Bucket settings require both a mode and a period. The period can be either Days or Years but you must select one.
-                You cannot specify Days and Years at the same time.
+                Specifies the Object Lock rule for the specified object. Enable this rule when you apply
+                ObjectLockConfiguration to a bucket. Bucket settings require both a mode and a period. The period can
+                be either Days or Years but you must select one. You cannot specify Days and Years at the same time.
 
                 * DefaultRetention (dict):
                     The default Object Lock retention mode and period that you want to apply to new objects placed
-                    in the specified bucket. Bucket settings require both a mode and a period. The period can be either Days or Years
-                    but you must select one. You cannot specify Days and Years at the same time.
+                    in the specified bucket. Bucket settings require both a mode and a period. The period can be either
+                    Days or Years but you must select one. You cannot specify Days and Years at the same time.
 
                     * Mode (str):
-                        The default Object Lock retention mode you want to apply to new objects placed in the specified bucket.
-                        Must be used with either Days or Years .
+                        The default Object Lock retention mode you want to apply to new objects placed in the specified
+                        bucket. Must be used with either Days or Years.
                     * Days (int):
-                        The number of days that you want to specify for the default retention period. Must be used with Mode .
+                        The number of days that you want to specify for the default retention period. Must be used with
+                        Mode.
                     * Years (int):
-                        The number of years that you want to specify for the default retention period. Must be used with Mode .
+                        The number of years that you want to specify for the default retention period. Must be used with
+                        Mode.
 
         tags(dict or list, Optional):
             dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
@@ -213,21 +215,16 @@ async def present(
         else:
             tags_list = tags
             tags_dict = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
+
     if resource_id:
-        resource = await hub.tool.boto3.resource.create(
-            ctx, "s3", "Bucket", resource_id
-        )
-        before = await hub.tool.boto3.resource.describe(resource)
-    if before:
-        convert_ret = await hub.exec.aws.s3.bucket.get(
+        before = await hub.exec.aws.s3.bucket.get(
             ctx, name=name, resource_id=resource_id
         )
-        result["result"] = convert_ret["result"]
-        if not result["result"]:
-            result["comment"] = result["comment"] + convert_ret["comment"]
+        if not before["result"]:
+            result["comment"] = before["comment"]
+            result["result"] = False
             return result
-        result["old_state"] = copy.deepcopy(convert_ret["ret"].get("ret"))
-
+        result["old_state"] = copy.deepcopy(before["ret"])
         plan_state = copy.deepcopy(result["old_state"])
         result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
             "aws.s3.bucket", name
@@ -338,13 +335,13 @@ async def present(
     if ctx.get("test", False):
         result["new_state"] = plan_state
     elif (not before) or resource_updated:
-        convert_ret = await hub.exec.aws.s3.bucket.get(
+        get_ret = await hub.exec.aws.s3.bucket.get(
             ctx, name=name, resource_id=resource_id
         )
-        result["result"] = convert_ret["result"]
-        if not result["result"]:
-            result["comment"] = result["comment"] + convert_ret["comment"]
-        result["new_state"] = copy.deepcopy(convert_ret["ret"].get("ret"))
+        result["result"] = get_ret["result"]
+        if not get_ret["result"]:
+            result["comment"] = result["comment"] + get_ret["comment"]
+        result["new_state"] = copy.deepcopy(get_ret["ret"])
     else:
         result["new_state"] = copy.deepcopy(result["old_state"])
     return result
@@ -381,36 +378,32 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     if not resource_id:
-        result["comment"] = result[
-            "comment"
-        ] + hub.tool.aws.comment_utils.already_absent_comment(
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
             resource_type="aws.s3.bucket", name=name
         )
         return result
-    resource = await hub.tool.boto3.resource.create(ctx, "s3", "Bucket", resource_id)
-    before = await hub.tool.boto3.resource.describe(resource)
 
-    if not before:
-        result["comment"] = result[
-            "comment"
-        ] + hub.tool.aws.comment_utils.already_absent_comment(
+    before = await hub.exec.aws.s3.bucket.get(
+        ctx=ctx, name=name, resource_id=resource_id
+    )
+
+    if not before["result"]:
+        result["comment"] = before["comment"]
+        result["result"] = False
+        return result
+
+    if not before["ret"]:
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.s3.bucket", name=name
+        )
+    elif ctx.get("test", False):
+        result["old_state"] = before["ret"]
+        result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
             resource_type="aws.s3.bucket", name=name
         )
         return result
     else:
-        convert_ret = await hub.exec.aws.s3.bucket.get(
-            ctx=ctx, name=name, resource_id=resource_id
-        )
-        result["result"] = convert_ret["result"]
-        if not result["result"]:
-            result["comment"] = result["comment"] + convert_ret["comment"]
-            return result
-        result["old_state"] = convert_ret["ret"].get("ret")
-        if ctx.get("test", False):
-            result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
-                resource_type="aws.s3.bucket", name=name
-            )
-            return result
+        result["old_state"] = before["ret"]
         ret = await hub.exec.boto3.client.s3.delete_bucket(ctx, Bucket=resource_id)
         result["result"] = ret["result"]
         if not result["result"]:
@@ -442,19 +435,24 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     for bucket in ret["ret"]["Buckets"]:
         resource_id = bucket.get("Name")
-        convert_ret = await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present(
-            ctx, idem_resource_name=resource_id
-        )
-        if not convert_ret["result"]:
+
+        try:
+            translated_resource = (
+                await hub.tool.aws.s3.conversion_utils.convert_raw_s3_to_present(
+                    ctx, idem_resource_name=resource_id
+                )
+            )
+        except Exception as e:
             hub.log.warning(
-                f"Could not describe s3 bucket '{resource_id}' with error {convert_ret['comment']}"
+                f"Could not describe s3 bucket '{resource_id}' with error {e}"
             )
             continue
-        translated_resource = convert_ret["ret"]
+
         result[resource_id] = {
             "aws.s3.bucket.present": [
                 {parameter_key: parameter_value}
                 for parameter_key, parameter_value in translated_resource.items()
             ]
         }
+
     return result
