@@ -9,7 +9,7 @@ async def search_raw(hub, ctx, name, resource_id: str = None) -> Dict:
         name(str):
             The name of the Idem state.
 
-        resource_id(str, optional):
+        resource_id(str, Optional):
             Aws logGroupNamePrefix (The prefix to match.)
 
     Returns:
