@@ -59,19 +59,27 @@ def find_more_than_one(hub, resource_type: str, resource_id: str) -> str:
     )
 
 
-def resource_status_updated_comment(
-    hub, resource_type: str, name: str, new_status: str
-) -> str:
+def update_status_comment(
+    hub, resource_type: str, name: str, resource_id: str, new_status: str
+) -> Tuple:
     return (
-        f"The status of the {resource_type} with name - {name} is updated to {new_status}",
+        f"Update status to {new_status} of {resource_type} with name - {name} is and id - {resource_id}",
+    )
+
+
+def would_update_status_comment(
+    hub, resource_type: str, name: str, resource_id: str, new_status: str
+) -> Tuple:
+    return (
+        f"Would update status to {new_status} of {resource_type} with name - {name} is and id - {resource_id}",
     )
 
 
 def would_update_resource_options_comment(
     hub,
     resource_type: str,
-    resource_id: str,
     name: str,
+    resource_id: str,
 ) -> Tuple:
     return (
         f"Would update options for {resource_type} resource with name - {name} and id - {resource_id}",
@@ -87,3 +95,9 @@ def update_resource_options_comment(
     return (
         f"Update options for {resource_type} resource with name - {name} and id - {resource_id}",
     )
+
+
+def invalid_parameter_provided_comment(
+    hub, parameter_name: str, resource_type: str, name: str
+) -> Tuple:
+    return f"Invalid {parameter_name} was provided for resource type - {resource_type} with name - {name}"
