@@ -10,7 +10,7 @@ async def get_tags_for_resource(hub, ctx, resource_arn: str):
     Args:
         hub:
         ctx:
-        resource_arn(string): aws resource arn
+        resource_arn(str): aws resource arn
 
     Returns:
         {"result": True|False, "comment": "A message tuple", "ret": Dict['str', Any]|None}
