@@ -17,7 +17,7 @@ async def search_raw(
     Fetch one or more ami's from AWS. The return will be in the same format as what the boto3 api returns.
 
     Args:
-        resource_id(str, optional):
+        resource_id(str, Optional):
             Resource ID of the ami.
 
         executable_users (list[str], Optional):
@@ -33,11 +33,11 @@ async def search_raw(
             If true , all deprecated AMIs are included in the response.
             If false , no deprecated AMIs are included in the response. If no value is specified, the default value is false .
 
-        filters(List, optional):
+        filters(List, Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images
 
-        tags(List, optional):
+        tags(List, Optional):
             The list of tags to filter by. For example, to find all resources that have a tag with the key
             "Owner" and the value "TeamA" , specify "tag:Owner" for the Dict key and "TeamA" for the Dict value.
 
