@@ -2,13 +2,14 @@
 Contains functions that are useful for describing instances in a consistent manner
 """
 import asyncio
+import base64
 from typing import Any
 from typing import Dict
 from typing import Tuple
 
 
 async def convert_to_present(
-    hub, ctx, describe_instances: Dict[str, Any]
+    hub, ctx, describe_instances: Dict[str, Any], name: str = None
 ) -> Dict[str, Any]:
     """
     Convert instances from ec2.describe_instances() to aws.ec2.instance.present states
@@ -24,7 +25,7 @@ async def convert_to_present(
             metadata_options = instance.get("MetadataOptions", {})
             private_dns_name_options = instance.get("PrivateDnsNameOptions", {})
             result[instance_id] = dict(
-                name=instance_id,
+                name=name or instance_id,
                 resource_id=instance_id,
                 image_id=instance.get("ImageId"),
                 instance_type=instance.get("InstanceType"),
@@ -56,7 +57,9 @@ async def convert_to_present(
                 disable_api_termination=None,
                 ram_disk_id=instance.get("RamdiskId"),
                 tags={tag["Key"]: tag["Value"] for tag in instance.get("Tags", [])},
-                iam_profile_arn=instance.get("IamInstanceProfile", {}).get("Arn"),
+                iam_instance_profile_arn=instance.get("IamInstanceProfile", {}).get(
+                    "Arn"
+                ),
                 instance_initiated_shutdown_behavior=None,
                 elastic_inference_accelerators=instance.get(
                     "ElasticInferenceAcceleratorAssociations"
@@ -209,6 +212,9 @@ def parse_launch_template_data(hub, **launch_config) -> Dict[str, Any]:
     spot_options = instance_market_options.get("SpotOptions", {})
     metadata_options = launch_config.get("MetadataOptions", {})
     private_dns_name_options = launch_config.get("PrivateDnsNameOptions", {})
+    user_data = launch_config.get("UserData")
+    if user_data:
+        user_data = base64.b64decode(user_data).decode()
 
     tags = {}
     for tag_spec in launch_config.get("TagSpecifications", []):
@@ -240,11 +246,11 @@ def parse_launch_template_data(hub, **launch_config) -> Dict[str, Any]:
         tenancy=placement.get("Tenancy"),
         spread_domain=placement.get("SpreadDomain"),
         host_resource_group_arn=placement.get("HostResourceGroupArn"),
-        user_data=launch_config.get("UserData"),
+        user_data=user_data,
         disable_api_termination=launch_config.get("DisableApiTermination"),
         ram_disk_id=launch_config.get("RamDiskId"),
         tags=tags,
-        # iam_profile_arn
+        # iam_instance_profile_arn
         instance_initiated_shutdown_behavior=launch_config.get(
             "InstanceInitiatedShutdownBehavior"
         ),
@@ -300,7 +306,10 @@ async def attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
         ctx, Attribute="userData", InstanceId=instance_id
     )
     if ret:
-        instance["user_data"] = ret.ret["UserData"]
+        user_data = ret.ret.get("UserData")
+        if user_data:
+            user_data = base64.b64decode(user_data).decode()
+        instance["user_data"] = user_data
 
     ret = await hub.exec.boto3.client.ec2.describe_instance_attribute(
         ctx, Attribute="disableApiTermination", InstanceId=instance_id
@@ -350,23 +359,29 @@ async def extended_attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
     """
     instance = {}
 
-    # iam_profile_arn
+    # iam_instance_profile_arn
     ret = await hub.exec.boto3.client.ec2.describe_iam_instance_profile_associations(
         ctx, Filters=[{"Name": "instance-id", "Values": [instance_id]}]
     )
     if ret:
-        instance["iam_profile_arn"] = {}
+        instance["iam_instance_profile_arn"] = {}
         for association in ret.ret["IamInstanceProfileAssociations"]:
             if association["State"] == "associating":
                 # Prefer reporting what will soon be true
-                instance["iam_profile_arn"] = association["IamInstanceProfile"]["Arn"]
+                instance["iam_instance_profile_arn"] = association[
+                    "IamInstanceProfile"
+                ]["Arn"]
                 break
             elif association["State"] == "associated":
                 # Fallback to the current configuration
-                instance["iam_profile_arn"] = association["IamInstanceProfile"]["Arn"]
+                instance["iam_instance_profile_arn"] = association[
+                    "IamInstanceProfile"
+                ]["Arn"]
                 break
             else:
-                instance["iam_profile_arn"] = association["IamInstanceProfile"]["Arn"]
+                instance["iam_instance_profile_arn"] = association[
+                    "IamInstanceProfile"
+                ]["Arn"]
                 # Don't break, this might be disassociated
 
     # sriov_net_support
@@ -376,7 +391,7 @@ async def extended_attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
     if ret:
         instance["sriov_net_support"] = ret.ret["SriovNetSupport"].get("Value")
 
-    # block_device_mappings
+    # volume attachments
     volume_attachments = {}
     ret = await hub.exec.boto3.client.ec2.describe_volumes(
         ctx, Filters=[{"Name": "attachment.instance-id", "Values": [instance_id]}]
@@ -390,6 +405,19 @@ async def extended_attributes(hub, ctx, *, instance_id: str) -> Dict[str, Any]:
 
     instance["volume_attachments"] = volume_attachments
 
+    # bootstrap
+    bootstraps = []
+
+    # Detect known bootstrap methods already running on the instance
+    heist_managers = hub.tool.heist.bootstrap.managers(hub.heist)
+    for heist_manager in heist_managers:
+        # TODO What is the actual function call that should be made?
+        # if hub.heist[heist_manager].exists():
+        #    bootstraps.append(heist_manager)
+        ...
+
+    instance["bootstrap"] = bootstraps
+
     return instance
 
 
