@@ -1,5 +1,8 @@
 from typing import List
 
+# The instance must be stopped to modify this value
+__update_state__ = "stopped"
+
 
 async def apply(
     hub, ctx, resource, *, old_value: bool, new_value: bool, comments: List[str]
@@ -23,10 +26,10 @@ async def apply(
             comments.append(ret.comment)
         return ret.result
     else:
-        ret = await hub.exec.boto3.client.ec2.modfiy_instance_attribute(
+        ret = await hub.exec.boto3.client.ec2.modify_instance_attribute(
             ctx,
             InstanceId=resource.id,
-            Attribute="ebsOptimized",
+            # Attribute="ebsOptimized",
             EbsOptimized={"Value": new_value},
         )
         if ret.comment:
