@@ -1,8 +1,5 @@
 from typing import List
 
-# Monitoring isn't supported by localstack
-__update_on_fail__ = "continue"
-
 
 async def apply(
     hub, ctx, resource, *, old_value: bool, new_value: bool, comments: List[str]
@@ -31,7 +28,6 @@ async def apply(
         ret = await hub.exec.boto3.client.ec2.unmonitor_instances(
             ctx, InstanceIds=[resource.id]
         )
-        await hub.tool.boto3.resource.exec(resource, "wait_until_stopped")
 
         if ret.comment:
             comments.append(ret.comment)
