@@ -15,11 +15,19 @@ async def apply(
         new_value: The desired value from the ec2 instance present state parameters
         comments: A running list of comments abound the update process
     """
-    ret = await hub.exec.boto3.client.ec2.associate_address(
-        ctx,
-        InstanceId=resource.id,
-        PrivateIpAddress=new_value,
-    )
-    if ret.comment:
-        comments.append(ret.comment)
-    return ret.result
+    if new_value is None:
+        ret = await hub.exec.boto3.client.ec2.reset_instance_attribute(
+            ctx, InstanceId=resource.id, Attribute="instanceType"
+        )
+        if ret.comment:
+            comments.append(ret.comment)
+        return ret.result
+    else:
+        ret = await hub.exec.boto3.client.ec2.associate_address(
+            ctx,
+            InstanceId=resource.id,
+            PrivateIpAddress=new_value,
+        )
+        if ret.comment:
+            comments.append(ret.comment)
+        return ret.result
