@@ -51,6 +51,10 @@ def convert_raw_cluster_to_present(
             "encryptionConfig": "encryption_config",
             "clientRequestToken": "client_request_token",
             "tags": "tags",
+            "endpoint": "endpoint",
+            "certificateAuthority": "certificate_authority",
+            "platformVersion": "platform_version",
+            "outpostConfig": "outpost_config",
         }
     )
 
@@ -63,6 +67,11 @@ def convert_raw_cluster_to_present(
                 else raw_resource.get(parameter_raw)
             )
 
+    if raw_resource.get("identity") and raw_resource.get("identity").get("oidc"):
+        resource_translated["identity"] = {
+            "oidc": raw_resource.get("identity").get("oidc").copy()
+        }
+
     return resource_translated
 
 
