@@ -18,7 +18,7 @@ async def convert_raw_elasticache_subnet_to_present(
 
      Args:
         raw_resource(Dict[str, str]): resource obtained from describe API
-        idem_resource_name(Text): name of idem resource
+        idem_resource_name(str): name of idem resource
 
     Return: Dict[str, Any]
     """
@@ -68,7 +68,7 @@ async def convert_raw_elasticache_parameter_group_to_present(
 
      Args:
         raw_resource(Dict[str, str]): resource obtained from describe API
-        idem_resource_name(Text): name of idem resource
+        idem_resource_name(str): name of idem resource
 
     Return: Dict[str, Any]
     """
@@ -119,7 +119,7 @@ async def convert_raw_elasticache_parameter_group_to_present(
     return result
 
 
-def convert_raw_elasticache_replication_group_to_present(
+async def convert_raw_elasticache_replication_group_to_present(
     hub,
     ctx,
     raw_resource: Dict[str, Any],
@@ -130,7 +130,7 @@ def convert_raw_elasticache_replication_group_to_present(
 
      Args:
         raw_resource(Dict[str, Any]): resource obtained from describe API
-        idem_resource_name(Text): name of idem resource
+        idem_resource_name(str): name of idem resource
 
     Return: Dict[str, Any]
     """
@@ -167,8 +167,11 @@ def convert_raw_elasticache_replication_group_to_present(
 
     if raw_resource.get("NodeGroups"):
         for node in raw_resource.get("NodeGroups"):
-            if "NodeGroupId" in node:
+            if not resource_translated.get("node_group_id") and "NodeGroupId" in node:
                 resource_translated["node_group_id"] = node.get("NodeGroupId")
+            if not resource_translated.get("port") and "PrimaryEndpoint" in node:
+                resource_translated["port"] = (node.get("PrimaryEndpoint")).get("Port")
+
     resource_translated["automatic_failover_enabled"] = bool(
         raw_resource.get("AutomaticFailover") == "enabled"
     )
@@ -182,4 +185,43 @@ def convert_raw_elasticache_replication_group_to_present(
         resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
             raw_resource.get("Tags")
         )
+
+    if raw_resource.get("MemberClusters"):
+
+        cache_cluster_id = raw_resource.get("MemberClusters")[0]
+
+        ret = await hub.exec.boto3.client.elasticache.describe_cache_clusters(
+            ctx, CacheClusterId=cache_cluster_id
+        )
+        if not ret["result"]:
+            hub.log.debug("Cannot describe cache clusters")
+
+        if ret["ret"].get("CacheClusters"):
+            cache_clusters_resource = ret["ret"].get("CacheClusters")[0]
+            security_groups = cache_clusters_resource.get("SecurityGroups")
+            security_group_ids = []
+            if security_groups:
+                for security_group in security_groups:
+                    security_group_ids.append(security_group.get("SecurityGroupId"))
+                resource_translated["security_group_ids"] = security_group_ids
+
+            cluster_parameters = OrderedDict(
+                {
+                    "EngineVersion": "engine_version",
+                    "PreferredMaintenanceWindow": "preferred_maintenance_window",
+                    "CacheSubnetGroupName": "cache_subnet_group_name",
+                }
+            )
+            for parameter_raw, parameter_present in cluster_parameters.items():
+                if parameter_raw in cache_clusters_resource:
+                    resource_translated[
+                        parameter_present
+                    ] = cache_clusters_resource.get(parameter_raw)
+            if "CacheParameterGroup" in cache_clusters_resource:
+                resource_translated[
+                    "cache_parameter_group_name"
+                ] = cache_clusters_resource["CacheParameterGroup"].get(
+                    "CacheParameterGroupName"
+                )
+
     return resource_translated
