@@ -38,3 +38,16 @@ async def convert_raw_detector_to_present(
     if detector_describe["DataSources"]:
         resource_translated["data_sources"] = data_sources_new
     return resource_translated
+
+
+def convert_raw_org_admin_account_to_present(
+    hub, raw_resource: Dict[str, Any], idem_resource_name: str
+) -> Dict[str, Any]:
+    resource_id = raw_resource.get("AdminAccountId")
+    resource_translated = {
+        "name": idem_resource_name,
+        "resource_id": resource_id,
+    }
+    if "AdminStatus" in raw_resource:
+        resource_translated["admin_status"] = raw_resource.get("AdminStatus")
+    return resource_translated
