@@ -83,5 +83,13 @@ async def convert_raw_lambda_function_to_present(
     if tags:
         new_function["tags"] = tags.copy()
 
+    new_function["invoke_arn"] = hub.tool.aws.arn_utils.build(
+        service="apigateway",
+        region=ctx["acct"]["region_name"],
+        account_id="lambda",
+        resource="path/2015-03-31/functions/"
+        + new_function["function_arn"]
+        + "/invocations",
+    )
     result["ret"] = new_function
     return result
