@@ -10,14 +10,14 @@ def convert_raw_function_event_invoke_config_to_present(
     function_name: str = None,
     idem_resource_name: str = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Convert AWS returned data structure to correct idem function_event_invoke_config present state
 
      Args:
         hub: required for functions in hub
         raw_resource(Dict): The aws response to convert
-        function_name (string, Optional): The name of the Lambda function
-        idem_resource_name(string, optional): An Idem name of the resource.
+        function_name (str, Optional): The name of the Lambda function
+        idem_resource_name(str, Optional): An Idem name of the resource.
 
     Returns: Valid idem state for function_event_invoke_config of type Dict['string', Any]
     """
@@ -52,13 +52,13 @@ async def update_function_event_invoke_config(
     current_state: Dict[str, Any],
     desired_state: Dict[str, Any],
 ):
-    r"""
+    """
     Updates configuration options for asynchronous invocation on a function
 
     Args:
         hub: required for functions in hub.
         ctx: context.
-        function_name(string): The name of the Lambda function
+        function_name(str): The name of the Lambda function
         current_state(Dict): Previous state of the resource
         desired_state(Dict): Parameters from SLS file.
 
