@@ -102,7 +102,7 @@ def create_change_batch_for_update(hub, action, resource_record) -> Any:
 
     Args:
         hub: The redistributed pop central hub.
-        action(Text): 'CREATE'|'DELETE'|'UPSERT' literal.
+        action(str): 'CREATE'|'DELETE'|'UPSERT' literal.
         resource_record(Any): Idem resource record instance.
 
     Returns:
