@@ -1,4 +1,3 @@
-"""Tool module for various conversion of Amazon S3 bucket resources."""
 import json
 from typing import Any
 from typing import Dict
@@ -7,10 +6,10 @@ from typing import Dict
 def convert_raw_bucket_notification_to_present(
     hub, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """Convert the s3 bucket notification configurations response to a common format.
+    """Convert the s3 bucket notification configurations response to a common format
 
     Args:
-        raw_resource(Dict[str, Any]):
+        raw_resource(dict):
             Dictionary of s3 bucket notification configurations
 
         bucket_name(str):
@@ -32,11 +31,11 @@ def convert_raw_bucket_notification_to_present(
 def convert_raw_bucket_logging_to_present(
     hub, ctx, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """Convert the s3 bucket logging configurations response to a common format.
+    """Convert the s3 bucket logging configurations response to a common format
 
     Args:
-        raw_resource(Dict[str, Any]):
-            Dictionary of s3 bucket logging configurations.
+        raw_resource(dict):
+            Dictionary of s3 bucket logging configurations
 
         bucket_name(str):
             Name of the bucket on which logging needs to be configured.
@@ -59,7 +58,7 @@ def convert_raw_bucket_logging_to_present(
 async def convert_raw_s3_to_present(
     hub, ctx, idem_resource_name: str = None
 ) -> Dict[str, Any]:
-    """Convert the s3 bucket configurations response to a common format.
+    """Convert the s3 bucket configurations response to a common format
 
     Args:
         idem_resource_name(str, Optional):
@@ -72,20 +71,17 @@ async def convert_raw_s3_to_present(
         "name": idem_resource_name,
         "resource_id": idem_resource_name,
     }
-    bucket_acl: dict = {}
-    result = dict(comment=(), result=True, ret=None)
+
     ret = await hub.exec.boto3.client.s3.get_object_lock_configuration(
         ctx, Bucket=idem_resource_name
     )
-    if not ret["result"]:
-        # Added error message check to continue if there is ObjectLockConfigurationNotFoundError exception else
-        # return the result
-        if "ObjectLockConfigurationNotFoundError" in str(ret["comment"]):
-            result["comment"] = result["comment"] + ret["comment"]
-        else:
-            result["comment"] = result["comment"] + ret["comment"]
-            result["result"] = False
-            return result
+    if not ret["result"] and "ObjectLockConfigurationNotFoundError" not in str(
+        ret["comment"]
+    ):
+        # Continue if there is ObjectLockConfigurationNotFoundError exception else
+        # throw an exception
+        raise Exception(ret["comment"])
+
     if ret["result"]:
         if ret["ret"]["ObjectLockConfiguration"]["ObjectLockEnabled"] == "Enabled":
             resource_translated["object_lock_enabled_for_bucket"] = True
@@ -99,9 +95,7 @@ async def convert_raw_s3_to_present(
         ctx, Bucket=idem_resource_name
     )
     if not ret["result"]:
-        result["comment"] = result["comment"] + ret["comment"]
-        result["result"] = False
-        return result
+        raise Exception(ret["comment"])
     if ret["result"] and ret["ret"]["LocationConstraint"]:
         resource_translated["create_bucket_configuration"] = {
             "LocationConstraint": ret["ret"]["LocationConstraint"]
@@ -109,15 +103,13 @@ async def convert_raw_s3_to_present(
     ret = await hub.exec.boto3.client.s3.get_bucket_ownership_controls(
         ctx, Bucket=idem_resource_name
     )
-    if not ret["result"]:
-        # Added error message check to continue if there is OwnershipControlsNotFoundError exception else
-        # return the result
-        if "OwnershipControlsNotFoundError" in str(ret["comment"]):
-            result["comment"] = result["comment"] + ret["comment"]
-        else:
-            result["comment"] = result["comment"] + ret["comment"]
-            result["result"] = False
-            return result
+    if not ret["result"] and "OwnershipControlsNotFoundError" not in str(
+        ret["comment"]
+    ):
+        # Continue if there is OwnershipControlsNotFoundError exception else
+        # throw an exception
+        raise Exception(ret["comment"])
+
     if (
         ret["result"]
         and ret["ret"]["OwnershipControls"]
@@ -127,16 +119,12 @@ async def convert_raw_s3_to_present(
             "Rules"
         ][0]["ObjectOwnership"]
     ret = await hub.exec.boto3.client.s3.get_bucket_acl(ctx, Bucket=idem_resource_name)
-    if not ret["result"]:
-        # Added error message check to continue if there is AccessControlListNotSupported exception else
-        # return the result
-        if "AccessControlListNotSupported" in str(ret["comment"]):
-            result["comment"] = result["comment"] + ret["comment"]
-        else:
-            result["comment"] = result["comment"] + ret["comment"]
-            result["result"] = False
-            return result
-    # checking first element in grants because for no permissions API returns empty array
+    if not ret["result"] and "AccessControlListNotSupported" not in str(ret["comment"]):
+        # Continue if there is AccessControlListNotSupported exception else
+        # throw an exception
+        raise Exception(ret["comment"])
+
+        # checking first element in grants because for no permissions API returns empty array
     full_control = ""
     read = ""
     read_acp = ""
@@ -182,27 +170,20 @@ async def convert_raw_s3_to_present(
     ret = await hub.exec.boto3.client.s3.get_bucket_tagging(
         ctx, Bucket=idem_resource_name
     )
-    if not ret["result"]:
+    if not ret["result"] and "NoSuchTagSet" not in str(ret["comment"]):
         # Added error message check to continue if there is NoSuchTagSet exception else return the result
-        if "NoSuchTagSet" in str(ret["comment"]):
-            result["comment"] = result["comment"] + ret["comment"]
-        else:
-            result["comment"] = result["comment"] + ret["comment"]
-            result["result"] = False
-            return result
+        raise Exception(ret["comment"])
+
     if ret["result"] and ret["ret"]["TagSet"]:
         resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
             ret["ret"]["TagSet"]
         )
-    result["ret"] = resource_translated
-
-    return result
+    return resource_translated
 
 
 def convert_raw_public_access_block_to_present(
     hub, bucket_name: str, public_access_block_configuration: Dict
 ) -> Dict[str, Any]:
-    """Util function to convert the s3 bucket public access block response to a common format."""
     translated_resource = {
         "name": f"{bucket_name}-public-access-block",
         "bucket": bucket_name,
@@ -249,7 +230,7 @@ def convert_raw_bucket_replication_to_present(
     """Convert the s3 bucket replication configurations response to a common format.
 
     Args:
-        raw_resource(Dict[str, Any]):
+        raw_resource(dict[str, Any]):
             Dictionary of s3 bucket replication configurations.
 
         bucket_name(str):
@@ -275,7 +256,7 @@ def convert_raw_acl_policy_to_present(
     """Util function to convert the s3 bucket policy response to a common format.
 
     Args:
-        raw_resource(Dict):
+        raw_resource(dict[str, Any]):
             S3 bucket policy response.
 
         bucket_name(str):
