@@ -37,5 +37,13 @@ def convert_search_filter_to_boto3(hub, filters: List) -> List:
     result = []
     if filters is not None:
         for fil in filters:
-            result.append({"Name": fil["name"], "Values": fil["values"]})
+            if "name" in fil:
+                name = fil["name"]
+            else:
+                name = fil["Name"]
+            if "values" in fil:
+                values = fil["values"]
+            else:
+                values = fil["Values"]
+            result.append({"Name": name, "Values": values})
     return result
